# -- coding: utf-8 --
# Created by LoginRadius Development Team
# Copyright 2019 LoginRadius Inc. All rights reserved.
#


class SmartLoginApi:

    def __init__(self, lr_object):
        """
        :param lr_object: this is the reference to the parent LoginRadius object.
        """
        self._lr_object = lr_object

    def smart_login_token_verification(self, verification_token, welcome_email_template=None):
        """This API verifies the provided token for Smart Login
        
        Args:
            verification_token: Verification token received in the email
            welcome_email_template: Name of the welcome email template
		
        Returns:
            Complete verified response data
        8.4.1
        """

        if(self._lr_object.is_null_or_whitespace(verification_token)):
            raise Exception(self._lr_object.get_validation_message("verification_token"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["verificationToken"] = verification_token
        if(not self._lr_object.is_null_or_whitespace(welcome_email_template)):
            query_parameters["welcomeEmailTemplate"] = welcome_email_template

        resource_path = "identity/v2/auth/email/smartlogin"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def smart_login_by_email(self, client_guid, email, redirect_url=None,
        smart_login_email_template=None, welcome_email_template=None):
        """This API sends a Smart Login link to the user's Email Id.
        
        Args:
            client_guid: Unique string used in the Smart Login request
            email: Email of the user
            redirect_url: Url where the user will redirect after success authentication
            smart_login_email_template: Email template for Smart Login link
            welcome_email_template: Name of the welcome email template
		
        Returns:
            Response containing Definition of Complete Validation data
        9.17.1
        """

        if(self._lr_object.is_null_or_whitespace(client_guid)):
            raise Exception(self._lr_object.get_validation_message("client_guid"))

        if(self._lr_object.is_null_or_whitespace(email)):
            raise Exception(self._lr_object.get_validation_message("email"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["clientGuid"] = client_guid
        query_parameters["email"] = email
        if(not self._lr_object.is_null_or_whitespace(redirect_url)):
            query_parameters["redirectUrl"] = redirect_url
        if(not self._lr_object.is_null_or_whitespace(smart_login_email_template)):
            query_parameters["smartLoginEmailTemplate"] = smart_login_email_template
        if(not self._lr_object.is_null_or_whitespace(welcome_email_template)):
            query_parameters["welcomeEmailTemplate"] = welcome_email_template

        resource_path = "identity/v2/auth/login/smartlogin"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def smart_login_by_user_name(self, client_guid, username, redirect_url=None,
        smart_login_email_template=None, welcome_email_template=None):
        """This API sends a Smart Login link to the user's Email Id.
        
        Args:
            client_guid: Unique string used in the Smart Login request
            username: UserName of the user
            redirect_url: Url where the user will redirect after success authentication
            smart_login_email_template: Email template for Smart Login link
            welcome_email_template: Name of the welcome email template
		
        Returns:
            Response containing Definition of Complete Validation data
        9.17.2
        """

        if(self._lr_object.is_null_or_whitespace(client_guid)):
            raise Exception(self._lr_object.get_validation_message("client_guid"))

        if(self._lr_object.is_null_or_whitespace(username)):
            raise Exception(self._lr_object.get_validation_message("username"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["clientGuid"] = client_guid
        query_parameters["username"] = username
        if(not self._lr_object.is_null_or_whitespace(redirect_url)):
            query_parameters["redirectUrl"] = redirect_url
        if(not self._lr_object.is_null_or_whitespace(smart_login_email_template)):
            query_parameters["smartLoginEmailTemplate"] = smart_login_email_template
        if(not self._lr_object.is_null_or_whitespace(welcome_email_template)):
            query_parameters["welcomeEmailTemplate"] = welcome_email_template

        resource_path = "identity/v2/auth/login/smartlogin"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def smart_login_ping(self, client_guid, fields=''):
        """This API is used to check if the Smart Login link has been clicked or not
        
        Args:
            client_guid: Unique string used in the Smart Login request
            fields: The fields parameter filters the API response so that the response only includes a specific set of fields
		
        Returns:
            Response containing User Profile Data and access token
        9.21.1
        """

        if(self._lr_object.is_null_or_whitespace(client_guid)):
            raise Exception(self._lr_object.get_validation_message("client_guid"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["clientGuid"] = client_guid
        if(not self._lr_object.is_null_or_whitespace(fields)):
            query_parameters["fields"] = fields

        resource_path = "identity/v2/auth/login/smartlogin/ping"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})



# -- coding: utf-8 --
# Created by LoginRadius Development Team
# Copyright 2019 LoginRadius Inc. All rights reserved.
#


class RoleApi:

    def __init__(self, lr_object):
        """
        :param lr_object: this is the reference to the parent LoginRadius object.
        """
        self._lr_object = lr_object

    def get_roles_by_uid(self, uid):
        """API is used to retrieve all the assigned roles of a particular User.
        
        Args:
            uid: UID, the unified identifier for each user account
		
        Returns:
            Response containing Definition of Complete Roles data
        18.6
        """

        if(self._lr_object.is_null_or_whitespace(uid)):
            raise Exception(self._lr_object.get_validation_message("uid"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["apiSecret"] = self._lr_object.get_api_secret()

        resource_path = "identity/v2/manage/account/" + uid + "/role"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def assign_roles_by_uid(self, account_roles_model, uid):
        """This API is used to assign your desired roles to a given user.
        
        Args:
            account_roles_model: Model Class containing Definition of payload for Create Role API
            uid: UID, the unified identifier for each user account
		
        Returns:
            Response containing Definition of Complete Roles data
        18.7
        """
        if(account_roles_model is None):
            raise Exception(self._lr_object.get_validation_message("account_roles_model"))

        if(self._lr_object.is_null_or_whitespace(uid)):
            raise Exception(self._lr_object.get_validation_message("uid"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["apiSecret"] = self._lr_object.get_api_secret()

        resource_path = "identity/v2/manage/account/" + uid + "/role"
        return self._lr_object.execute("PUT", resource_path, query_parameters, account_roles_model)

    def unassign_roles_by_uid(self, account_roles_model, uid):
        """This API is used to unassign roles from a user.
        
        Args:
            account_roles_model: Model Class containing Definition of payload for Create Role API
            uid: UID, the unified identifier for each user account
		
        Returns:
            Response containing Definition of Delete Request
        18.8
        """
        if(account_roles_model is None):
            raise Exception(self._lr_object.get_validation_message("account_roles_model"))

        if(self._lr_object.is_null_or_whitespace(uid)):
            raise Exception(self._lr_object.get_validation_message("uid"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["apiSecret"] = self._lr_object.get_api_secret()

        resource_path = "identity/v2/manage/account/" + uid + "/role"
        return self._lr_object.execute("DELETE", resource_path, query_parameters, account_roles_model)

    def get_role_context_by_uid(self, uid):
        """This API Gets the contexts that have been configured and the associated roles and permissions.
        
        Args:
            uid: UID, the unified identifier for each user account
		
        Returns:
            Complete user RoleContext data
        18.9
        """

        if(self._lr_object.is_null_or_whitespace(uid)):
            raise Exception(self._lr_object.get_validation_message("uid"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["apiSecret"] = self._lr_object.get_api_secret()

        resource_path = "identity/v2/manage/account/" + uid + "/rolecontext"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def get_role_context_by_context_name(self, context_name):
        """The API is used to retrieve role context by the context name.
        
        Args:
            context_name: Name of context
		
        Returns:
            Complete user RoleContext data
        18.10
        """

        if(self._lr_object.is_null_or_whitespace(context_name)):
            raise Exception(self._lr_object.get_validation_message("context_name"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["apiSecret"] = self._lr_object.get_api_secret()

        resource_path = "identity/v2/manage/account/rolecontext/" + context_name
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def update_role_context_by_uid(self, account_role_context_model, uid):
        """This API creates a Context with a set of Roles
        
        Args:
            account_role_context_model: Model Class containing Definition of RoleContext payload
            uid: UID, the unified identifier for each user account
		
        Returns:
            Complete user RoleContext data
        18.11
        """
        if(account_role_context_model is None):
            raise Exception(self._lr_object.get_validation_message("account_role_context_model"))

        if(self._lr_object.is_null_or_whitespace(uid)):
            raise Exception(self._lr_object.get_validation_message("uid"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["apiSecret"] = self._lr_object.get_api_secret()

        resource_path = "identity/v2/manage/account/" + uid + "/rolecontext"
        return self._lr_object.execute("PUT", resource_path, query_parameters, account_role_context_model)

    def delete_role_context_by_uid(self, context_name, uid):
        """This API Deletes the specified Role Context
        
        Args:
            context_name: Name of context
            uid: UID, the unified identifier for each user account
		
        Returns:
            Response containing Definition of Delete Request
        18.12
        """

        if(self._lr_object.is_null_or_whitespace(context_name)):
            raise Exception(self._lr_object.get_validation_message("context_name"))

        if(self._lr_object.is_null_or_whitespace(uid)):
            raise Exception(self._lr_object.get_validation_message("uid"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["apiSecret"] = self._lr_object.get_api_secret()

        resource_path = "identity/v2/manage/account/" + uid + "/rolecontext/" + context_name
        return self._lr_object.execute("DELETE", resource_path, query_parameters, {})

    def delete_roles_from_role_context_by_uid(self, context_name, role_context_remove_role_model, uid):
        """This API Deletes the specified Role from a Context.
        
        Args:
            context_name: Name of context
            role_context_remove_role_model: Model Class containing Definition of payload for RoleContextRemoveRole API
            uid: UID, the unified identifier for each user account
		
        Returns:
            Response containing Definition of Delete Request
        18.13
        """

        if(self._lr_object.is_null_or_whitespace(context_name)):
            raise Exception(self._lr_object.get_validation_message("context_name"))
        if(role_context_remove_role_model is None):
            raise Exception(self._lr_object.get_validation_message("role_context_remove_role_model"))

        if(self._lr_object.is_null_or_whitespace(uid)):
            raise Exception(self._lr_object.get_validation_message("uid"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["apiSecret"] = self._lr_object.get_api_secret()

        resource_path = "identity/v2/manage/account/" + uid + "/rolecontext/" + context_name + "/role"
        return self._lr_object.execute("DELETE", resource_path, query_parameters, role_context_remove_role_model)

    def delete_additional_permission_from_role_context_by_uid(self, context_name, role_context_additional_permission_remove_role_model, uid):
        """This API Deletes Additional Permissions from Context.
        
        Args:
            context_name: Name of context
            role_context_additional_permission_remove_role_model: Model Class containing Definition of payload for RoleContextAdditionalPermissionRemoveRole API
            uid: UID, the unified identifier for each user account
		
        Returns:
            Response containing Definition of Delete Request
        18.14
        """

        if(self._lr_object.is_null_or_whitespace(context_name)):
            raise Exception(self._lr_object.get_validation_message("context_name"))
        if(role_context_additional_permission_remove_role_model is None):
            raise Exception(self._lr_object.get_validation_message("role_context_additional_permission_remove_role_model"))

        if(self._lr_object.is_null_or_whitespace(uid)):
            raise Exception(self._lr_object.get_validation_message("uid"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["apiSecret"] = self._lr_object.get_api_secret()

        resource_path = "identity/v2/manage/account/" + uid + "/rolecontext/" + context_name + "/additionalpermission"
        return self._lr_object.execute("DELETE", resource_path, query_parameters, role_context_additional_permission_remove_role_model)

    def get_roles_list(self):
        """This API retrieves the complete list of created roles with permissions of your app.
        
        Returns:
            Complete user Roles List data
        41.1
        """

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["apiSecret"] = self._lr_object.get_api_secret()

        resource_path = "identity/v2/manage/role"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def create_roles(self, roles_model):
        """This API creates a role with permissions.
        
        Args:
            roles_model: Model Class containing Definition of payload for Roles API
		
        Returns:
            Complete user Roles data
        41.2
        """
        if(roles_model is None):
            raise Exception(self._lr_object.get_validation_message("roles_model"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["apiSecret"] = self._lr_object.get_api_secret()

        resource_path = "identity/v2/manage/role"
        return self._lr_object.execute("POST", resource_path, query_parameters, roles_model)

    def delete_role(self, role):
        """This API is used to delete the role.
        
        Args:
            role: Created RoleName
		
        Returns:
            Response containing Definition of Delete Request
        41.3
        """

        if(self._lr_object.is_null_or_whitespace(role)):
            raise Exception(self._lr_object.get_validation_message("role"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["apiSecret"] = self._lr_object.get_api_secret()

        resource_path = "identity/v2/manage/role/" + role
        return self._lr_object.execute("DELETE", resource_path, query_parameters, {})

    def add_role_permissions(self, permissions_model, role):
        """This API is used to add permissions to a given role.
        
        Args:
            permissions_model: Model Class containing Definition for PermissionsModel Property
            role: Created RoleName
		
        Returns:
            Response containing Definition of Complete role data
        41.4
        """
        if(permissions_model is None):
            raise Exception(self._lr_object.get_validation_message("permissions_model"))

        if(self._lr_object.is_null_or_whitespace(role)):
            raise Exception(self._lr_object.get_validation_message("role"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["apiSecret"] = self._lr_object.get_api_secret()

        resource_path = "identity/v2/manage/role/" + role + "/permission"
        return self._lr_object.execute("PUT", resource_path, query_parameters, permissions_model)

    def remove_role_permissions(self, permissions_model, role):
        """API is used to remove permissions from a role.
        
        Args:
            permissions_model: Model Class containing Definition for PermissionsModel Property
            role: Created RoleName
		
        Returns:
            Response containing Definition of Complete role data
        41.5
        """
        if(permissions_model is None):
            raise Exception(self._lr_object.get_validation_message("permissions_model"))

        if(self._lr_object.is_null_or_whitespace(role)):
            raise Exception(self._lr_object.get_validation_message("role"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["apiSecret"] = self._lr_object.get_api_secret()

        resource_path = "identity/v2/manage/role/" + role + "/permission"
        return self._lr_object.execute("DELETE", resource_path, query_parameters, permissions_model)



# -- coding: utf-8 --
# Created by LoginRadius Development Team
# Copyright 2019 LoginRadius Inc. All rights reserved.
#


class AuthenticationApi:

    def __init__(self, lr_object):
        """
        :param lr_object: this is the reference to the parent LoginRadius object.
        """
        self._lr_object = lr_object

    def get_security_questions_by_email(self, email):
        """This API is used to retrieve the list of questions that are configured on the respective LoginRadius site.
        
        Args:
            email: Email of the user
		
        Returns:
            Response containing Definition for Complete SecurityQuestions data
        2.1
        """

        if(self._lr_object.is_null_or_whitespace(email)):
            raise Exception(self._lr_object.get_validation_message("email"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["email"] = email

        resource_path = "identity/v2/auth/securityquestion/email"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def get_security_questions_by_user_name(self, user_name):
        """This API is used to retrieve the list of questions that are configured on the respective LoginRadius site.
        
        Args:
            user_name: UserName of the user
		
        Returns:
            Response containing Definition for Complete SecurityQuestions data
        2.2
        """

        if(self._lr_object.is_null_or_whitespace(user_name)):
            raise Exception(self._lr_object.get_validation_message("user_name"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["userName"] = user_name

        resource_path = "identity/v2/auth/securityquestion/username"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def get_security_questions_by_phone(self, phone):
        """This API is used to retrieve the list of questions that are configured on the respective LoginRadius site.
        
        Args:
            phone: The Registered Phone Number
		
        Returns:
            Response containing Definition for Complete SecurityQuestions data
        2.3
        """

        if(self._lr_object.is_null_or_whitespace(phone)):
            raise Exception(self._lr_object.get_validation_message("phone"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["phone"] = phone

        resource_path = "identity/v2/auth/securityquestion/phone"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def get_security_questions_by_access_token(self, access_token):
        """This API is used to retrieve the list of questions that are configured on the respective LoginRadius site.
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
		
        Returns:
            Response containing Definition for Complete SecurityQuestions data
        2.4
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        resource_path = "identity/v2/auth/securityquestion/accesstoken"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def auth_validate_access_token(self, access_token):
        """This api validates access token, if valid then returns a response with its expiry otherwise error.
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
		
        Returns:
            Response containing Definition of Complete Token data
        4.1
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        resource_path = "identity/v2/auth/access_token/validate"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def auth_in_validate_access_token(self, access_token, prevent_refresh=False):
        """This api call invalidates the active access token or expires an access token's validity.
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            prevent_refresh: Boolean value that when set as true, in addition of the access token being invalidated, it will no longer have the capability of being refreshed.
		
        Returns:
            Response containing Definition of Complete Validation data
        4.2
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        if(prevent_refresh is not None):
            query_parameters["preventRefresh"] = prevent_refresh

        resource_path = "identity/v2/auth/access_token/invalidate"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def get_access_token_info(self, access_token):
        """This api call provide the active access token Information
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
		
        Returns:
            Response containing Definition of Token Information
        4.3
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        resource_path = "identity/v2/auth/access_token"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def get_profile_by_access_token(self, access_token, fields='', email_template=None,
        verification_url=None, welcome_email_template=None):
        """This API retrieves a copy of the user data based on the access token.
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            fields: The fields parameter filters the API response so that the response only includes a specific set of fields
            email_template: 
            verification_url: 
            welcome_email_template: 
		
        Returns:
            Response containing Definition for Complete profile data
        5.2
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        if(not self._lr_object.is_null_or_whitespace(email_template)):
            query_parameters["emailTemplate"] = email_template
        if(not self._lr_object.is_null_or_whitespace(fields)):
            query_parameters["fields"] = fields
        if(not self._lr_object.is_null_or_whitespace(verification_url)):
            query_parameters["verificationUrl"] = verification_url
        if(not self._lr_object.is_null_or_whitespace(welcome_email_template)):
            query_parameters["welcomeEmailTemplate"] = welcome_email_template

        resource_path = "identity/v2/auth/account"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def send_welcome_email(self, access_token, welcome_email_template=None):
        """This API sends a welcome email
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            welcome_email_template: Name of the welcome email template
		
        Returns:
            Response containing Definition of Complete Validation data
        5.3
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        if(not self._lr_object.is_null_or_whitespace(welcome_email_template)):
            query_parameters["welcomeEmailTemplate"] = welcome_email_template

        resource_path = "identity/v2/auth/account/sendwelcomeemail"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def update_profile_by_access_token(self, access_token, user_profile_update_model, email_template=None,
        fields='', null_support=None, sms_template=None, verification_url=None):
        """This API is used to update the user's profile by passing the access token.
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            user_profile_update_model: Model Class containing Definition of payload for User Profile update API
            email_template: Email template name
            fields: The fields parameter filters the API response so that the response only includes a specific set of fields
            null_support: Boolean, pass true if you wish to update any user profile field with a NULL value, You can get the details
            sms_template: SMS Template name
            verification_url: Email verification url
		
        Returns:
            Response containing Definition of Complete Validation and UserProfile data
        5.4
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))
        if(user_profile_update_model is None):
            raise Exception(self._lr_object.get_validation_message("user_profile_update_model"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        if(not self._lr_object.is_null_or_whitespace(email_template)):
            query_parameters["emailTemplate"] = email_template
        if(not self._lr_object.is_null_or_whitespace(fields)):
            query_parameters["fields"] = fields
        if(null_support is not None):
            query_parameters["nullSupport"] = null_support
        if(not self._lr_object.is_null_or_whitespace(sms_template)):
            query_parameters["smsTemplate"] = sms_template
        if(not self._lr_object.is_null_or_whitespace(verification_url)):
            query_parameters["verificationUrl"] = verification_url

        resource_path = "identity/v2/auth/account"
        return self._lr_object.execute("PUT", resource_path, query_parameters, user_profile_update_model)

    def delete_account_with_email_confirmation(self, access_token, delete_url=None, email_template=None):
        """This API will send a confirmation email for account deletion to the customer's email when passed the customer's access token
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            delete_url: Url of the site
            email_template: Email template name
		
        Returns:
            Response containing Definition of Delete Request
        5.5
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        if(not self._lr_object.is_null_or_whitespace(delete_url)):
            query_parameters["deleteUrl"] = delete_url
        if(not self._lr_object.is_null_or_whitespace(email_template)):
            query_parameters["emailTemplate"] = email_template

        resource_path = "identity/v2/auth/account"
        return self._lr_object.execute("DELETE", resource_path, query_parameters, {})

    def delete_account_by_delete_token(self, deletetoken):
        """This API is used to delete an account by passing it a delete token.
        
        Args:
            deletetoken: Delete token received in the email
		
        Returns:
            Response containing Definition of Complete Validation data
        5.6
        """

        if(self._lr_object.is_null_or_whitespace(deletetoken)):
            raise Exception(self._lr_object.get_validation_message("deletetoken"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["deletetoken"] = deletetoken

        resource_path = "identity/v2/auth/account/delete"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def unlock_account_by_token(self, access_token, unlock_profile_model):
        """This API is used to allow a customer with a valid access token to unlock their account provided that they successfully pass the prompted Bot Protection challenges. The Block or Suspend block types are not applicable for this API. For additional details see our Auth Security Configuration documentation.You are only required to pass the Post Parameters that correspond to the prompted challenges.
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            unlock_profile_model: Payload containing Unlock Profile API
		
        Returns:
            Response containing Definition of Complete Validation data
        5.15
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))
        if(unlock_profile_model is None):
            raise Exception(self._lr_object.get_validation_message("unlock_profile_model"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        resource_path = "identity/v2/auth/account/unlock"
        return self._lr_object.execute("PUT", resource_path, query_parameters, unlock_profile_model)

    def get_profile_by_ping(self, client_guid, email_template=None, fields='',
        verification_url=None, welcome_email_template=None):
        """This API is used to get a user's profile using the clientGuid parameter if no callback feature enabled
        
        Args:
            client_guid: ClientGuid
            email_template: EmailTemplate
            fields: Fields
            verification_url: VerificationUrl
            welcome_email_template: WelcomeEmailTemplate
		
        Returns:
            Response containing User Profile Data and access token
        5.16
        """

        if(self._lr_object.is_null_or_whitespace(client_guid)):
            raise Exception(self._lr_object.get_validation_message("client_guid"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["clientGuid"] = client_guid
        if(not self._lr_object.is_null_or_whitespace(email_template)):
            query_parameters["emailTemplate"] = email_template
        if(not self._lr_object.is_null_or_whitespace(fields)):
            query_parameters["fields"] = fields
        if(not self._lr_object.is_null_or_whitespace(verification_url)):
            query_parameters["verificationUrl"] = verification_url
        if(not self._lr_object.is_null_or_whitespace(welcome_email_template)):
            query_parameters["welcomeEmailTemplate"] = welcome_email_template

        resource_path = "identity/v2/auth/account/ping"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def check_email_availability(self, email):
        """This API is used to check the email exists or not on your site.
        
        Args:
            email: Email of the user
		
        Returns:
            Response containing Definition Complete ExistResponse data
        8.1
        """

        if(self._lr_object.is_null_or_whitespace(email)):
            raise Exception(self._lr_object.get_validation_message("email"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["email"] = email

        resource_path = "identity/v2/auth/email"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def verify_email(self, verification_token, fields='', url=None,
        welcome_email_template=None):
        """This API is used to verify the email of user. Note: This API will only return the full profile if you have 'Enable auto login after email verification' set in your LoginRadius Admin Console's Email Workflow settings under 'Verification Email'.
        
        Args:
            verification_token: Verification token received in the email
            fields: The fields parameter filters the API response so that the response only includes a specific set of fields
            url: Mention URL to log the main URL(Domain name) in Database.
            welcome_email_template: Name of the welcome email template
		
        Returns:
            Response containing Definition of Complete Validation, UserProfile data and Access Token
        8.2
        """

        if(self._lr_object.is_null_or_whitespace(verification_token)):
            raise Exception(self._lr_object.get_validation_message("verification_token"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["verificationToken"] = verification_token
        if(not self._lr_object.is_null_or_whitespace(fields)):
            query_parameters["fields"] = fields
        if(not self._lr_object.is_null_or_whitespace(url)):
            query_parameters["url"] = url
        if(not self._lr_object.is_null_or_whitespace(welcome_email_template)):
            query_parameters["welcomeEmailTemplate"] = welcome_email_template

        resource_path = "identity/v2/auth/email"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def verify_email_by_otp(self, email_verification_by_otp_model, fields='', url=None,
        welcome_email_template=None):
        """This API is used to verify the email of user when the OTP Email verification flow is enabled, please note that you must contact LoginRadius to have this feature enabled.
        
        Args:
            email_verification_by_otp_model: Model Class containing Definition for EmailVerificationByOtpModel API
            fields: The fields parameter filters the API response so that the response only includes a specific set of fields
            url: Mention URL to log the main URL(Domain name) in Database.
            welcome_email_template: Name of the welcome email template
		
        Returns:
            Response containing Definition of Complete Validation, UserProfile data and Access Token
        8.3
        """
        if(email_verification_by_otp_model is None):
            raise Exception(self._lr_object.get_validation_message("email_verification_by_otp_model"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        if(not self._lr_object.is_null_or_whitespace(fields)):
            query_parameters["fields"] = fields
        if(not self._lr_object.is_null_or_whitespace(url)):
            query_parameters["url"] = url
        if(not self._lr_object.is_null_or_whitespace(welcome_email_template)):
            query_parameters["welcomeEmailTemplate"] = welcome_email_template

        resource_path = "identity/v2/auth/email"
        return self._lr_object.execute("PUT", resource_path, query_parameters, email_verification_by_otp_model)

    def add_email(self, access_token, email, type,
        email_template=None, verification_url=None):
        """This API is used to add additional emails to a user's account.
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            email: user's email
            type: String to identify the type of parameter
            email_template: Email template name
            verification_url: Email verification url
		
        Returns:
            Response containing Definition of Complete Validation data
        8.5
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        if(self._lr_object.is_null_or_whitespace(email)):
            raise Exception(self._lr_object.get_validation_message("email"))

        if(self._lr_object.is_null_or_whitespace(type)):
            raise Exception(self._lr_object.get_validation_message("type"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        if(not self._lr_object.is_null_or_whitespace(email_template)):
            query_parameters["emailTemplate"] = email_template
        if(not self._lr_object.is_null_or_whitespace(verification_url)):
            query_parameters["verificationUrl"] = verification_url

        body_parameters = {}
        body_parameters["email"] = email
        body_parameters["type"] = type

        resource_path = "identity/v2/auth/email"
        return self._lr_object.execute("POST", resource_path, query_parameters, body_parameters)

    def remove_email(self, access_token, email):
        """This API is used to remove additional emails from a user's account.
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            email: user's email
		
        Returns:
            Response containing Definition of Delete Request
        8.6
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        if(self._lr_object.is_null_or_whitespace(email)):
            raise Exception(self._lr_object.get_validation_message("email"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        body_parameters = {}
        body_parameters["email"] = email

        resource_path = "identity/v2/auth/email"
        return self._lr_object.execute("DELETE", resource_path, query_parameters, body_parameters)

    def login_by_email(self, email_authentication_model, email_template=None, fields='',
        login_url=None, verification_url=None):
        """This API retrieves a copy of the user data based on the Email
        
        Args:
            email_authentication_model: Model Class containing Definition of payload for Email Authentication API
            email_template: Email template name
            fields: The fields parameter filters the API response so that the response only includes a specific set of fields
            login_url: Url where the user is logging from
            verification_url: Email verification url
		
        Returns:
            Response containing User Profile Data and access token
        9.2.1
        """
        if(email_authentication_model is None):
            raise Exception(self._lr_object.get_validation_message("email_authentication_model"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        if(not self._lr_object.is_null_or_whitespace(email_template)):
            query_parameters["emailTemplate"] = email_template
        if(not self._lr_object.is_null_or_whitespace(fields)):
            query_parameters["fields"] = fields
        if(not self._lr_object.is_null_or_whitespace(login_url)):
            query_parameters["loginUrl"] = login_url
        if(not self._lr_object.is_null_or_whitespace(verification_url)):
            query_parameters["verificationUrl"] = verification_url

        resource_path = "identity/v2/auth/login"
        return self._lr_object.execute("POST", resource_path, query_parameters, email_authentication_model)

    def login_by_user_name(self, user_name_authentication_model, email_template=None, fields='',
        login_url=None, verification_url=None):
        """This API retrieves a copy of the user data based on the Username
        
        Args:
            user_name_authentication_model: Model Class containing Definition of payload for Username Authentication API
            email_template: Email template name
            fields: The fields parameter filters the API response so that the response only includes a specific set of fields
            login_url: Url where the user is logging from
            verification_url: Email verification url
		
        Returns:
            Response containing User Profile Data and access token
        9.2.2
        """
        if(user_name_authentication_model is None):
            raise Exception(self._lr_object.get_validation_message("user_name_authentication_model"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        if(not self._lr_object.is_null_or_whitespace(email_template)):
            query_parameters["emailTemplate"] = email_template
        if(not self._lr_object.is_null_or_whitespace(fields)):
            query_parameters["fields"] = fields
        if(not self._lr_object.is_null_or_whitespace(login_url)):
            query_parameters["loginUrl"] = login_url
        if(not self._lr_object.is_null_or_whitespace(verification_url)):
            query_parameters["verificationUrl"] = verification_url

        resource_path = "identity/v2/auth/login"
        return self._lr_object.execute("POST", resource_path, query_parameters, user_name_authentication_model)

    def forgot_password(self, email, reset_password_url, email_template=None):
        """This API is used to send the reset password url to a specified account. Note: If you have the UserName workflow enabled, you may replace the 'email' parameter with 'username'
        
        Args:
            email: user's email
            reset_password_url: Url to which user should get re-directed to for resetting the password
            email_template: Email template name
		
        Returns:
            Response containing Definition of Complete Validation data
        10.1
        """

        if(self._lr_object.is_null_or_whitespace(email)):
            raise Exception(self._lr_object.get_validation_message("email"))

        if(self._lr_object.is_null_or_whitespace(reset_password_url)):
            raise Exception(self._lr_object.get_validation_message("reset_password_url"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["resetPasswordUrl"] = reset_password_url
        if(not self._lr_object.is_null_or_whitespace(email_template)):
            query_parameters["emailTemplate"] = email_template

        body_parameters = {}
        body_parameters["email"] = email

        resource_path = "identity/v2/auth/password"
        return self._lr_object.execute("POST", resource_path, query_parameters, body_parameters)

    def reset_password_by_security_answer_and_email(self, reset_password_by_security_answer_and_email_model):
        """This API is used to reset password for the specified account by security question
        
        Args:
            reset_password_by_security_answer_and_email_model: Model Class containing Definition of payload for ResetPasswordBySecurityAnswerAndEmail API
		
        Returns:
            Response containing Definition of Validation data and access token
        10.3.1
        """
        if(reset_password_by_security_answer_and_email_model is None):
            raise Exception(self._lr_object.get_validation_message("reset_password_by_security_answer_and_email_model"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        resource_path = "identity/v2/auth/password/securityanswer"
        return self._lr_object.execute("PUT", resource_path, query_parameters, reset_password_by_security_answer_and_email_model)

    def reset_password_by_security_answer_and_phone(self, reset_password_by_security_answer_and_phone_model):
        """This API is used to reset password for the specified account by security question
        
        Args:
            reset_password_by_security_answer_and_phone_model: Model Class containing Definition of payload for ResetPasswordBySecurityAnswerAndPhone API
		
        Returns:
            Response containing Definition of Validation data and access token
        10.3.2
        """
        if(reset_password_by_security_answer_and_phone_model is None):
            raise Exception(self._lr_object.get_validation_message("reset_password_by_security_answer_and_phone_model"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        resource_path = "identity/v2/auth/password/securityanswer"
        return self._lr_object.execute("PUT", resource_path, query_parameters, reset_password_by_security_answer_and_phone_model)

    def reset_password_by_security_answer_and_user_name(self, reset_password_by_security_answer_and_user_name_model):
        """This API is used to reset password for the specified account by security question
        
        Args:
            reset_password_by_security_answer_and_user_name_model: Model Class containing Definition of payload for ResetPasswordBySecurityAnswerAndUserName API
		
        Returns:
            Response containing Definition of Validation data and access token
        10.3.3
        """
        if(reset_password_by_security_answer_and_user_name_model is None):
            raise Exception(self._lr_object.get_validation_message("reset_password_by_security_answer_and_user_name_model"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        resource_path = "identity/v2/auth/password/securityanswer"
        return self._lr_object.execute("PUT", resource_path, query_parameters, reset_password_by_security_answer_and_user_name_model)

    def reset_password_by_reset_token(self, reset_password_by_reset_token_model):
        """This API is used to set a new password for the specified account.
        
        Args:
            reset_password_by_reset_token_model: Model Class containing Definition of payload for ResetToken API
		
        Returns:
            Response containing Definition of Validation data and access token
        10.7.1
        """
        if(reset_password_by_reset_token_model is None):
            raise Exception(self._lr_object.get_validation_message("reset_password_by_reset_token_model"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        resource_path = "identity/v2/auth/password/reset"
        return self._lr_object.execute("PUT", resource_path, query_parameters, reset_password_by_reset_token_model)

    def reset_password_by_email_otp(self, reset_password_by_email_and_otp_model):
        """This API is used to set a new password for the specified account.
        
        Args:
            reset_password_by_email_and_otp_model: Model Class containing Definition of payload for ResetPasswordByEmailAndOtp API
		
        Returns:
            Response containing Definition of Validation data and access token
        10.7.2
        """
        if(reset_password_by_email_and_otp_model is None):
            raise Exception(self._lr_object.get_validation_message("reset_password_by_email_and_otp_model"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        resource_path = "identity/v2/auth/password/reset"
        return self._lr_object.execute("PUT", resource_path, query_parameters, reset_password_by_email_and_otp_model)

    def reset_password_by_otp_and_user_name(self, reset_password_by_user_name_model):
        """This API is used to set a new password for the specified account if you are using the username as the unique identifier in your workflow
        
        Args:
            reset_password_by_user_name_model: Model Class containing Definition of payload for ResetPasswordByUserName API
		
        Returns:
            Response containing Definition of Validation data and access token
        10.7.3
        """
        if(reset_password_by_user_name_model is None):
            raise Exception(self._lr_object.get_validation_message("reset_password_by_user_name_model"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        resource_path = "identity/v2/auth/password/reset"
        return self._lr_object.execute("PUT", resource_path, query_parameters, reset_password_by_user_name_model)

    def change_password(self, access_token, new_password, old_password):
        """This API is used to change the accounts password based on the previous password
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            new_password: New password
            old_password: User's current password
		
        Returns:
            Response containing Definition of Complete Validation data
        10.8
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        if(self._lr_object.is_null_or_whitespace(new_password)):
            raise Exception(self._lr_object.get_validation_message("new_password"))

        if(self._lr_object.is_null_or_whitespace(old_password)):
            raise Exception(self._lr_object.get_validation_message("old_password"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        body_parameters = {}
        body_parameters["newPassword"] = new_password
        body_parameters["oldPassword"] = old_password

        resource_path = "identity/v2/auth/password/change"
        return self._lr_object.execute("PUT", resource_path, query_parameters, body_parameters)

    def unlink_social_identities(self, access_token, provider, provider_id):
        """This API is used to unlink up a social provider account with the specified account based on the access token and the social providers user access token. The unlinked account will automatically get removed from your database.
        
        Args:
            access_token: Access_Token
            provider: Name of the provider
            provider_id: Unique ID of the linked account
		
        Returns:
            Response containing Definition of Delete Request
        12.2
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        if(self._lr_object.is_null_or_whitespace(provider)):
            raise Exception(self._lr_object.get_validation_message("provider"))

        if(self._lr_object.is_null_or_whitespace(provider_id)):
            raise Exception(self._lr_object.get_validation_message("provider_id"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        body_parameters = {}
        body_parameters["provider"] = provider
        body_parameters["providerId"] = provider_id

        resource_path = "identity/v2/auth/socialidentity"
        return self._lr_object.execute("DELETE", resource_path, query_parameters, body_parameters)

    def link_social_identities(self, access_token, candidate_token):
        """This API is used to link up a social provider account with an existing LoginRadius account on the basis of access token and the social providers user access token.
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            candidate_token: Access token of the account to be linked
		
        Returns:
            Response containing Definition of Complete Validation data
        12.4
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        if(self._lr_object.is_null_or_whitespace(candidate_token)):
            raise Exception(self._lr_object.get_validation_message("candidate_token"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        body_parameters = {}
        body_parameters["candidateToken"] = candidate_token

        resource_path = "identity/v2/auth/socialidentity"
        return self._lr_object.execute("POST", resource_path, query_parameters, body_parameters)

    def link_social_identities_by_ping(self, access_token, client_guid):
        """This API is used to link up a social provider account with an existing LoginRadius account on the basis of ping and the social providers user access token.
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            client_guid: Unique ID generated by client
		
        Returns:
            Response containing Definition of Complete Validation data
        12.5
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        if(self._lr_object.is_null_or_whitespace(client_guid)):
            raise Exception(self._lr_object.get_validation_message("client_guid"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        body_parameters = {}
        body_parameters["clientGuid"] = client_guid

        resource_path = "identity/v2/auth/socialidentity"
        return self._lr_object.execute("POST", resource_path, query_parameters, body_parameters)

    def set_or_change_user_name(self, access_token, username):
        """This API is used to set or change UserName by access token.
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            username: Username of the user
		
        Returns:
            Response containing Definition of Complete Validation data
        13.1
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        if(self._lr_object.is_null_or_whitespace(username)):
            raise Exception(self._lr_object.get_validation_message("username"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        body_parameters = {}
        body_parameters["username"] = username

        resource_path = "identity/v2/auth/username"
        return self._lr_object.execute("PUT", resource_path, query_parameters, body_parameters)

    def check_user_name_availability(self, username):
        """This API is used to check the UserName exists or not on your site.
        
        Args:
            username: UserName of the user
		
        Returns:
            Response containing Definition Complete ExistResponse data
        13.2
        """

        if(self._lr_object.is_null_or_whitespace(username)):
            raise Exception(self._lr_object.get_validation_message("username"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["username"] = username

        resource_path = "identity/v2/auth/username"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def accept_privacy_policy(self, access_token, fields=''):
        """This API is used to update the privacy policy stored in the user's profile by providing the access token of the user accepting the privacy policy
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            fields: The fields parameter filters the API response so that the response only includes a specific set of fields
		
        Returns:
            Response containing Definition for Complete profile data
        15.1
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        if(not self._lr_object.is_null_or_whitespace(fields)):
            query_parameters["fields"] = fields

        resource_path = "identity/v2/auth/privacypolicy/accept"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def get_privacy_policy_history_by_access_token(self, access_token):
        """This API will return all the accepted privacy policies for the user by providing the access token of that user.
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
		
        Returns:
            Complete Policy History data
        15.2
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        resource_path = "identity/v2/auth/privacypolicy/history"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def user_registration_by_email(self, auth_user_registration_model, sott, email_template=None,
        fields='', options='', verification_url=None, welcome_email_template=None):
        """This API creates a user in the database as well as sends a verification email to the user.
        
        Args:
            auth_user_registration_model: Model Class containing Definition of payload for Auth User Registration API
            sott: LoginRadius Secured One Time Token
            email_template: Email template name
            fields: The fields parameter filters the API response so that the response only includes a specific set of fields
            options: PreventVerificationEmail (Specifying this value prevents the verification email from being sent. Only applicable if you have the optional email verification flow)
            verification_url: Email verification url
            welcome_email_template: Name of the welcome email template
		
        Returns:
            Response containing Definition of Complete Validation, UserProfile data and Access Token
        17.1.1
        """
        if(auth_user_registration_model is None):
            raise Exception(self._lr_object.get_validation_message("auth_user_registration_model"))

        if(self._lr_object.is_null_or_whitespace(sott)):
            raise Exception(self._lr_object.get_validation_message("sott"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["sott"] = sott
        if(not self._lr_object.is_null_or_whitespace(email_template)):
            query_parameters["emailTemplate"] = email_template
        if(not self._lr_object.is_null_or_whitespace(fields)):
            query_parameters["fields"] = fields
        if(not self._lr_object.is_null_or_whitespace(options)):
            query_parameters["options"] = options
        if(not self._lr_object.is_null_or_whitespace(verification_url)):
            query_parameters["verificationUrl"] = verification_url
        if(not self._lr_object.is_null_or_whitespace(welcome_email_template)):
            query_parameters["welcomeEmailTemplate"] = welcome_email_template

        resource_path = "identity/v2/auth/register"
        return self._lr_object.execute("POST", resource_path, query_parameters, auth_user_registration_model)

    def user_registration_by_captcha(self, auth_user_registration_model_with_captcha, email_template=None, fields='',
        options='', sms_template=None, verification_url=None, welcome_email_template=None):
        """This API creates a user in the database as well as sends a verification email to the user.
        
        Args:
            auth_user_registration_model_with_captcha: Model Class containing Definition of payload for Auth User Registration by Recaptcha API
            email_template: Email template name
            fields: The fields parameter filters the API response so that the response only includes a specific set of fields
            options: PreventVerificationEmail (Specifying this value prevents the verification email from being sent. Only applicable if you have the optional email verification flow)
            sms_template: SMS Template name
            verification_url: Email verification url
            welcome_email_template: Name of the welcome email template
		
        Returns:
            Response containing Definition of Complete Validation, UserProfile data and Access Token
        17.2
        """
        if(auth_user_registration_model_with_captcha is None):
            raise Exception(self._lr_object.get_validation_message("auth_user_registration_model_with_captcha"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        if(not self._lr_object.is_null_or_whitespace(email_template)):
            query_parameters["emailTemplate"] = email_template
        if(not self._lr_object.is_null_or_whitespace(fields)):
            query_parameters["fields"] = fields
        if(not self._lr_object.is_null_or_whitespace(options)):
            query_parameters["options"] = options
        if(not self._lr_object.is_null_or_whitespace(sms_template)):
            query_parameters["smsTemplate"] = sms_template
        if(not self._lr_object.is_null_or_whitespace(verification_url)):
            query_parameters["verificationUrl"] = verification_url
        if(not self._lr_object.is_null_or_whitespace(welcome_email_template)):
            query_parameters["welcomeEmailTemplate"] = welcome_email_template

        resource_path = "identity/v2/auth/register/captcha"
        return self._lr_object.execute("POST", resource_path, query_parameters, auth_user_registration_model_with_captcha)

    def auth_resend_email_verification(self, email, email_template=None, verification_url=None):
        """This API resends the verification email to the user.
        
        Args:
            email: user's email
            email_template: Email template name
            verification_url: Email verification url
		
        Returns:
            Response containing Definition of Complete Validation data
        17.3
        """

        if(self._lr_object.is_null_or_whitespace(email)):
            raise Exception(self._lr_object.get_validation_message("email"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        if(not self._lr_object.is_null_or_whitespace(email_template)):
            query_parameters["emailTemplate"] = email_template
        if(not self._lr_object.is_null_or_whitespace(verification_url)):
            query_parameters["verificationUrl"] = verification_url

        body_parameters = {}
        body_parameters["email"] = email

        resource_path = "identity/v2/auth/register"
        return self._lr_object.execute("PUT", resource_path, query_parameters, body_parameters)



# -- coding: utf-8 --
# Created by LoginRadius Development Team
# Copyright 2019 LoginRadius Inc. All rights reserved.
#


class PasswordLessLoginApi:

    def __init__(self, lr_object):
        """
        :param lr_object: this is the reference to the parent LoginRadius object.
        """
        self._lr_object = lr_object

    def passwordless_login_phone_verification(self, password_less_login_otp_model, fields='', sms_template=None):
        """This API verifies an account by OTP and allows the customer to login.
        
        Args:
            password_less_login_otp_model: Model Class containing Definition of payload for PasswordLessLoginOtpModel API
            fields: The fields parameter filters the API response so that the response only includes a specific set of fields
            sms_template: SMS Template name
		
        Returns:
            Response containing User Profile Data and access token
        9.6
        """
        if(password_less_login_otp_model is None):
            raise Exception(self._lr_object.get_validation_message("password_less_login_otp_model"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        if(not self._lr_object.is_null_or_whitespace(fields)):
            query_parameters["fields"] = fields
        if(not self._lr_object.is_null_or_whitespace(sms_template)):
            query_parameters["smsTemplate"] = sms_template

        resource_path = "identity/v2/auth/login/passwordlesslogin/otp/verify"
        return self._lr_object.execute("PUT", resource_path, query_parameters, password_less_login_otp_model)

    def passwordless_login_by_phone(self, phone, sms_template=None):
        """API can be used to send a One-time Passcode (OTP) provided that the account has a verified PhoneID
        
        Args:
            phone: The Registered Phone Number
            sms_template: SMS Template name
		
        Returns:
            Response Containing Definition of SMS Data
        9.15
        """

        if(self._lr_object.is_null_or_whitespace(phone)):
            raise Exception(self._lr_object.get_validation_message("phone"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["phone"] = phone
        if(not self._lr_object.is_null_or_whitespace(sms_template)):
            query_parameters["smsTemplate"] = sms_template

        resource_path = "identity/v2/auth/login/passwordlesslogin/otp"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def passwordless_login_by_email(self, email, password_less_login_template=None, verification_url=None):
        """This API is used to send a Passwordless Login verification link to the provided Email ID
        
        Args:
            email: Email of the user
            password_less_login_template: Passwordless Login Template Name
            verification_url: Email verification url
		
        Returns:
            Response containing Definition of Complete Validation data
        9.18.1
        """

        if(self._lr_object.is_null_or_whitespace(email)):
            raise Exception(self._lr_object.get_validation_message("email"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["email"] = email
        if(not self._lr_object.is_null_or_whitespace(password_less_login_template)):
            query_parameters["passwordLessLoginTemplate"] = password_less_login_template
        if(not self._lr_object.is_null_or_whitespace(verification_url)):
            query_parameters["verificationUrl"] = verification_url

        resource_path = "identity/v2/auth/login/passwordlesslogin/email"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def passwordless_login_by_user_name(self, username, password_less_login_template=None, verification_url=None):
        """This API is used to send a Passwordless Login Verification Link to a customer by providing their UserName
        
        Args:
            username: UserName of the user
            password_less_login_template: Passwordless Login Template Name
            verification_url: Email verification url
		
        Returns:
            Response containing Definition of Complete Validation data
        9.18.2
        """

        if(self._lr_object.is_null_or_whitespace(username)):
            raise Exception(self._lr_object.get_validation_message("username"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["username"] = username
        if(not self._lr_object.is_null_or_whitespace(password_less_login_template)):
            query_parameters["passwordLessLoginTemplate"] = password_less_login_template
        if(not self._lr_object.is_null_or_whitespace(verification_url)):
            query_parameters["verificationUrl"] = verification_url

        resource_path = "identity/v2/auth/login/passwordlesslogin/email"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def passwordless_login_verification(self, verification_token, fields='', welcome_email_template=None):
        """This API is used to verify the Passwordless Login verification link. Note: If you are using Passwordless Login by Phone you will need to use the Passwordless Login Phone Verification API
        
        Args:
            verification_token: Verification token received in the email
            fields: The fields parameter filters the API response so that the response only includes a specific set of fields
            welcome_email_template: Name of the welcome email template
		
        Returns:
            Response containing User Profile Data and access token
        9.19
        """

        if(self._lr_object.is_null_or_whitespace(verification_token)):
            raise Exception(self._lr_object.get_validation_message("verification_token"))

        query_parameters = {}
        query_parameters["apikey"] = self._lr_object.get_api_key()
        query_parameters["verificationToken"] = verification_token
        if(not self._lr_object.is_null_or_whitespace(fields)):
            query_parameters["fields"] = fields
        if(not self._lr_object.is_null_or_whitespace(welcome_email_template)):
            query_parameters["welcomeEmailTemplate"] = welcome_email_template

        resource_path = "identity/v2/auth/login/passwordlesslogin/email/verify"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def passwordless_login_verification_by_email_and_otp(self, password_less_login_by_email_and_otp_model, fields=''):
        """This API is used to verify the otp sent to the email when doing a passwordless login. 
        
        Args:
            password_less_login_by_email_and_otp_model: payload
            fields: Fields
		
        Returns:
            Response containing User Profile Data and access token
        9.23
        """
        if(password_less_login_by_email_and_otp_model is None):
            raise Exception(self._lr_object.get_validation_message("password_less_login_by_email_and_otp_model"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        if(not self._lr_object.is_null_or_whitespace(fields)):
            query_parameters["fields"] = fields

        resource_path = "identity/v2/auth/login/passwordlesslogin/email/verifyotp"
        return self._lr_object.execute("POST", resource_path, query_parameters, password_less_login_by_email_and_otp_model)

    def passwordless_login_verification_by_user_name_and_otp(self, password_less_login_by_user_name_and_otp_model, fields=''):
        """This API is used to verify the otp sent to the email when doing a passwordless login.
        
        Args:
            password_less_login_by_user_name_and_otp_model: payload
            fields: Fields
		
        Returns:
            Response containing User Profile Data and access token
        9.24
        """
        if(password_less_login_by_user_name_and_otp_model is None):
            raise Exception(self._lr_object.get_validation_message("password_less_login_by_user_name_and_otp_model"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        if(not self._lr_object.is_null_or_whitespace(fields)):
            query_parameters["fields"] = fields

        resource_path = "identity/v2/auth/login/passwordlesslogin/username/verifyotp"
        return self._lr_object.execute("POST", resource_path, query_parameters, password_less_login_by_user_name_and_otp_model)



#!/usr/bin/python
#################################################
# Class for User Registration                   #
#################################################
# This is the main class to communicate with    #
# LoginRadius' Unified User Registration API.
#                                               #
# Please note that some API calls are for       #
# premium or enterprise members only.           #
# In which case, an exception will be raised.   #
#################################################
# Copyright 2019 LoginRadius Inc.               #
# - www.LoginRadius.com                         #
#################################################
# This file is part of the LoginRadius SDK      #
# package.                                      #
#################################################


class LoginRadiusExceptions(Exception):
    """
    This is the base for all LoginRadius Exceptions. Makes dealing with exceptions easy!
    """

    def __init__(self):
        pass

    def __str__(self):
        return ""


class Exceptions:
    """
    Common exceptions used by LoginRadius.
    """

    def __init__(self):
        pass

    class RequestsLibraryDated(LoginRadiusExceptions):
        """
        Raise exception if module requests is outdated.
        By default 0.12 is included in Python. We need at least version 2.0
        """

        def __init__(self, version):
            self.version = str(version)

        def __str__(self):
            return "LoginRadius needs at least requests 2.0, found: " \
                + self.version + "\nPlease upgrade to the latest version."

    class InvalidLibrary(LoginRadiusExceptions):
        """
        Raised on trying to change library to through _settings on invalid library argument.
        """

        def __init__(self, library):
            self.library = library

        def __str__(self):
            return "Invalid library string given. Got: " + str(self.library) + ". Valid cases: 'requests' or " + \
                "'urllib2'"

    class NoAPISecret(LoginRadiusExceptions):
        """
        Raised on construction of the LoginRadius object,
        if no API_SECRET has been set for the class.
        """

        def __init__(self):
            pass

        def __str__(self):
            return "No API_SECRET set. Please initialize a API_SECRET first.\n" \
                + "ie. LoginRadius.API_SECRET = \"Really_Secret_Key\""

    class NoAPIKey(LoginRadiusExceptions):
        """
        Raised on construction of the LoginRadius object,
        if no API_KEY has been set for the class.
        """

        def __init__(self):
            pass

        def __str__(self):
            return "No API_KEY set. Please initialize a APP_KEY first.\n" \
                + "ie. LoginRadius.API_Key = \"Really_Application_Key\""

    class MissingJsonResponseParameter(LoginRadiusExceptions):
        """
        Raised if construction of namedtuple would fail
        because missing expected response from LoginRadius API.
        """

        def __init__(self, missing_parameter, raw=None):
            self.missing_parameter = missing_parameter
            self.raw = raw

        def __str__(self):
            exception_string = "Expected parameter from JSON response does not exist." + \
                " Expected: " + self.missing_parameter + " but was not in" + \
                " the dictionary."
            if self.raw:
                exception_string += " Instead, we got: " + str(self.raw)
                return exception_string

    class TokenExpired(LoginRadiusExceptions):
        """
        Raised if the request cannot be completed because the access token has expired.
        """

        def __init__(self, time):
            self.time = time

        def __str__(self):
            return "The request cannot be completed because the token has expired. " + \
                "The token expired on: " + self.time

    class FeatureNotSupported(LoginRadiusExceptions):
        """
        Raised if the request cannot be completed because your account/API access does not include this.
        """

        def __init__(self):
            pass

        def __str__(self):
            return "Your LoginRadius site doesn't have permission to access this endpoint, please contact " + \
                "LoginRadius support if you need more information."

    class UnknownJsonError(LoginRadiusExceptions):
        """
        Raised if cannot determine error number from Json
        """

        def __init__(self, result):
            self.result = result

        def __str__(self):
            return str(self.result)

    class APIKeyInvalid(LoginRadiusExceptions):
        """
        Raised if you entered your API wrong, or not at all.
        """

        def __init__(self):
            pass

        def __str__(self):
            return "The LoginRadius API Key is not valid, please double check your account."

    class APISecretInvalid(LoginRadiusExceptions):
        """
        Raised if you your API Secret is invalid.
        """

        def __init__(self):
            pass

        def __str__(self):
            return "The LoginRadius API Secret is not valid, please double check your account."

    class InvalidRequestToken(LoginRadiusExceptions):
        """
        Raised if you your request token is invalid from the POST request.
        """

        def __init__(self):
            pass

        def __str__(self):
            return "The LoginRadius Request Token is invalid, please verify the authentication response."

    class RequestTokenExpired(LoginRadiusExceptions):
        """
        Raised if you your request token has expired from the POST request.
        """

        def __init__(self):
            pass

        def __str__(self):
            return "The LoginRadius Request Token has expired, please verify the authentication response."

    class InvalidAccessToken(LoginRadiusExceptions):
        """
        Raised if you access token is invalid.
        """

        def __init__(self):
            pass

        def __str__(self):
            return "The LoginRadius Access Token has expired, please get a new token from the LoginRadius API."

    class ParameterMissing(LoginRadiusExceptions):
        """
        Raised if a parameter in the GET or POST request is missing.
        """

        def __init__(self):
            pass

        def __str__(self):
            return "A parameter is missing in the request, please check all parameters in the API call."

    class ParameterNotFormatted(LoginRadiusExceptions):
        """
        Raised if a parameter in the GET or POST request is not formatted properly for the provider.
        """

        def __init__(self):
            pass

        def __str__(self):
            return "A parameter is not formatted well in the request, please check all the parameters in the API call."

    class EndPointNotSupported(LoginRadiusExceptions):
        """
        Raised if a the endpoint is not supported by the provider which correlates to the token.
        """

        def __init__(self):
            pass

        def __str__(self):
            return "The requested endpoint is not supported by the current ID provider, " + \
                "please check the API support page at http://www.loginradius.com/datapoints"



# -- coding: utf-8 --
# Created by LoginRadius Development Team
# Copyright 2019 LoginRadius Inc. All rights reserved.
#


class RiskBasedAuthenticationApi:

    def __init__(self, lr_object):
        """
        :param lr_object: this is the reference to the parent LoginRadius object.
        """
        self._lr_object = lr_object

    def rba_login_by_email(self, email_authentication_model, email_template=None, fields='',
        login_url=None, password_delegation=None, password_delegation_app=None, rba_browser_email_template=None,
        rba_browser_sms_template=None, rba_city_email_template=None, rba_city_sms_template=None, rba_country_email_template=None,
        rba_country_sms_template=None, rba_ip_email_template=None, rba_ip_sms_template=None, rba_oneclick_email_template=None,
        rba_otp_sms_template=None, sms_template=None, verification_url=None):
        """This API retrieves a copy of the user data based on the Email
        
        Args:
            email_authentication_model: Model Class containing Definition of payload for Email Authentication API
            email_template: Email template name
            fields: The fields parameter filters the API response so that the response only includes a specific set of fields
            login_url: Url where the user is logging from
            password_delegation: Password Delegation Allows you to use a third-party service to store your passwords rather than LoginRadius Cloud storage.
            password_delegation_app: RiskBased Authentication Password Delegation App
            rba_browser_email_template: Risk Based Authentication Browser EmailTemplate
            rba_browser_sms_template: Risk Based Authentication Browser Sms Template
            rba_city_email_template: Risk Based Authentication City Email Template
            rba_city_sms_template: Risk Based Authentication City SmsTemplate
            rba_country_email_template: Risk Based Authentication Country EmailTemplate
            rba_country_sms_template: Risk Based Authentication Country SmsTemplate
            rba_ip_email_template: Risk Based Authentication Ip EmailTemplate
            rba_ip_sms_template: Risk Based Authentication Ip SmsTemplate
            rba_oneclick_email_template: Risk Based Authentication Oneclick EmailTemplate
            rba_otp_sms_template: Risk Based Authentication Oneclick EmailTemplate
            sms_template: SMS Template name
            verification_url: Email verification url
		
        Returns:
            Response containing User Profile Data and access token
        9.2.4
        """
        if(email_authentication_model is None):
            raise Exception(self._lr_object.get_validation_message("email_authentication_model"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        if(not self._lr_object.is_null_or_whitespace(email_template)):
            query_parameters["emailTemplate"] = email_template
        if(not self._lr_object.is_null_or_whitespace(fields)):
            query_parameters["fields"] = fields
        if(not self._lr_object.is_null_or_whitespace(login_url)):
            query_parameters["loginUrl"] = login_url
        if(password_delegation is not None):
            query_parameters["passwordDelegation"] = password_delegation
        if(not self._lr_object.is_null_or_whitespace(password_delegation_app)):
            query_parameters["passwordDelegationApp"] = password_delegation_app
        if(not self._lr_object.is_null_or_whitespace(rba_browser_email_template)):
            query_parameters["rbaBrowserEmailTemplate"] = rba_browser_email_template
        if(not self._lr_object.is_null_or_whitespace(rba_browser_sms_template)):
            query_parameters["rbaBrowserSmsTemplate"] = rba_browser_sms_template
        if(not self._lr_object.is_null_or_whitespace(rba_city_email_template)):
            query_parameters["rbaCityEmailTemplate"] = rba_city_email_template
        if(not self._lr_object.is_null_or_whitespace(rba_city_sms_template)):
            query_parameters["rbaCitySmsTemplate"] = rba_city_sms_template
        if(not self._lr_object.is_null_or_whitespace(rba_country_email_template)):
            query_parameters["rbaCountryEmailTemplate"] = rba_country_email_template
        if(not self._lr_object.is_null_or_whitespace(rba_country_sms_template)):
            query_parameters["rbaCountrySmsTemplate"] = rba_country_sms_template
        if(not self._lr_object.is_null_or_whitespace(rba_ip_email_template)):
            query_parameters["rbaIpEmailTemplate"] = rba_ip_email_template
        if(not self._lr_object.is_null_or_whitespace(rba_ip_sms_template)):
            query_parameters["rbaIpSmsTemplate"] = rba_ip_sms_template
        if(not self._lr_object.is_null_or_whitespace(rba_oneclick_email_template)):
            query_parameters["rbaOneclickEmailTemplate"] = rba_oneclick_email_template
        if(not self._lr_object.is_null_or_whitespace(rba_otp_sms_template)):
            query_parameters["rbaOTPSmsTemplate"] = rba_otp_sms_template
        if(not self._lr_object.is_null_or_whitespace(sms_template)):
            query_parameters["smsTemplate"] = sms_template
        if(not self._lr_object.is_null_or_whitespace(verification_url)):
            query_parameters["verificationUrl"] = verification_url

        resource_path = "identity/v2/auth/login"
        return self._lr_object.execute("POST", resource_path, query_parameters, email_authentication_model)

    def rba_login_by_user_name(self, user_name_authentication_model, email_template=None, fields='',
        login_url=None, password_delegation=None, password_delegation_app=None, rba_browser_email_template=None,
        rba_browser_sms_template=None, rba_city_email_template=None, rba_city_sms_template=None, rba_country_email_template=None,
        rba_country_sms_template=None, rba_ip_email_template=None, rba_ip_sms_template=None, rba_oneclick_email_template=None,
        rba_otp_sms_template=None, sms_template=None, verification_url=None):
        """This API retrieves a copy of the user data based on the Username
        
        Args:
            user_name_authentication_model: Model Class containing Definition of payload for Username Authentication API
            email_template: Email template name
            fields: The fields parameter filters the API response so that the response only includes a specific set of fields
            login_url: Url where the user is logging from
            password_delegation: Password Delegation Allows you to use a third-party service to store your passwords rather than LoginRadius Cloud storage.
            password_delegation_app: RiskBased Authentication Password Delegation App
            rba_browser_email_template: Risk Based Authentication Browser EmailTemplate
            rba_browser_sms_template: Risk Based Authentication Browser Sms Template
            rba_city_email_template: Risk Based Authentication City Email Template
            rba_city_sms_template: Risk Based Authentication City SmsTemplate
            rba_country_email_template: Risk Based Authentication Country EmailTemplate
            rba_country_sms_template: Risk Based Authentication Country SmsTemplate
            rba_ip_email_template: Risk Based Authentication Ip EmailTemplate
            rba_ip_sms_template: Risk Based Authentication Ip SmsTemplate
            rba_oneclick_email_template: Risk Based Authentication Oneclick EmailTemplate
            rba_otp_sms_template: Risk Based Authentication OTPSmsTemplate
            sms_template: SMS Template name
            verification_url: Email verification url
		
        Returns:
            Response containing User Profile Data and access token
        9.2.5
        """
        if(user_name_authentication_model is None):
            raise Exception(self._lr_object.get_validation_message("user_name_authentication_model"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        if(not self._lr_object.is_null_or_whitespace(email_template)):
            query_parameters["emailTemplate"] = email_template
        if(not self._lr_object.is_null_or_whitespace(fields)):
            query_parameters["fields"] = fields
        if(not self._lr_object.is_null_or_whitespace(login_url)):
            query_parameters["loginUrl"] = login_url
        if(password_delegation is not None):
            query_parameters["passwordDelegation"] = password_delegation
        if(not self._lr_object.is_null_or_whitespace(password_delegation_app)):
            query_parameters["passwordDelegationApp"] = password_delegation_app
        if(not self._lr_object.is_null_or_whitespace(rba_browser_email_template)):
            query_parameters["rbaBrowserEmailTemplate"] = rba_browser_email_template
        if(not self._lr_object.is_null_or_whitespace(rba_browser_sms_template)):
            query_parameters["rbaBrowserSmsTemplate"] = rba_browser_sms_template
        if(not self._lr_object.is_null_or_whitespace(rba_city_email_template)):
            query_parameters["rbaCityEmailTemplate"] = rba_city_email_template
        if(not self._lr_object.is_null_or_whitespace(rba_city_sms_template)):
            query_parameters["rbaCitySmsTemplate"] = rba_city_sms_template
        if(not self._lr_object.is_null_or_whitespace(rba_country_email_template)):
            query_parameters["rbaCountryEmailTemplate"] = rba_country_email_template
        if(not self._lr_object.is_null_or_whitespace(rba_country_sms_template)):
            query_parameters["rbaCountrySmsTemplate"] = rba_country_sms_template
        if(not self._lr_object.is_null_or_whitespace(rba_ip_email_template)):
            query_parameters["rbaIpEmailTemplate"] = rba_ip_email_template
        if(not self._lr_object.is_null_or_whitespace(rba_ip_sms_template)):
            query_parameters["rbaIpSmsTemplate"] = rba_ip_sms_template
        if(not self._lr_object.is_null_or_whitespace(rba_oneclick_email_template)):
            query_parameters["rbaOneclickEmailTemplate"] = rba_oneclick_email_template
        if(not self._lr_object.is_null_or_whitespace(rba_otp_sms_template)):
            query_parameters["rbaOTPSmsTemplate"] = rba_otp_sms_template
        if(not self._lr_object.is_null_or_whitespace(sms_template)):
            query_parameters["smsTemplate"] = sms_template
        if(not self._lr_object.is_null_or_whitespace(verification_url)):
            query_parameters["verificationUrl"] = verification_url

        resource_path = "identity/v2/auth/login"
        return self._lr_object.execute("POST", resource_path, query_parameters, user_name_authentication_model)

    def rba_login_by_phone(self, phone_authentication_model, email_template=None, fields='',
        login_url=None, password_delegation=None, password_delegation_app=None, rba_browser_email_template=None,
        rba_browser_sms_template=None, rba_city_email_template=None, rba_city_sms_template=None, rba_country_email_template=None,
        rba_country_sms_template=None, rba_ip_email_template=None, rba_ip_sms_template=None, rba_oneclick_email_template=None,
        rba_otp_sms_template=None, sms_template=None, verification_url=None):
        """This API retrieves a copy of the user data based on the Phone
        
        Args:
            phone_authentication_model: Model Class containing Definition of payload for PhoneAuthenticationModel API
            email_template: Email template name
            fields: The fields parameter filters the API response so that the response only includes a specific set of fields
            login_url: Url where the user is logging from
            password_delegation: Password Delegation Allows you to use a third-party service to store your passwords rather than LoginRadius Cloud storage.
            password_delegation_app: RiskBased Authentication Password Delegation App
            rba_browser_email_template: Risk Based Authentication Browser EmailTemplate
            rba_browser_sms_template: Risk Based Authentication Browser Sms Template
            rba_city_email_template: Risk Based Authentication City Email Template
            rba_city_sms_template: Risk Based Authentication City SmsTemplate
            rba_country_email_template: Risk Based Authentication Country EmailTemplate
            rba_country_sms_template: Risk Based Authentication Country SmsTemplate
            rba_ip_email_template: Risk Based Authentication Ip EmailTemplate
            rba_ip_sms_template: Risk Based Authentication Ip SmsTemplate
            rba_oneclick_email_template: Risk Based Authentication Oneclick EmailTemplate
            rba_otp_sms_template: Risk Based Authentication OTPSmsTemplate
            sms_template: SMS Template name
            verification_url: Email verification url
		
        Returns:
            Response containing User Profile Data and access token
        9.2.6
        """
        if(phone_authentication_model is None):
            raise Exception(self._lr_object.get_validation_message("phone_authentication_model"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        if(not self._lr_object.is_null_or_whitespace(email_template)):
            query_parameters["emailTemplate"] = email_template
        if(not self._lr_object.is_null_or_whitespace(fields)):
            query_parameters["fields"] = fields
        if(not self._lr_object.is_null_or_whitespace(login_url)):
            query_parameters["loginUrl"] = login_url
        if(password_delegation is not None):
            query_parameters["passwordDelegation"] = password_delegation
        if(not self._lr_object.is_null_or_whitespace(password_delegation_app)):
            query_parameters["passwordDelegationApp"] = password_delegation_app
        if(not self._lr_object.is_null_or_whitespace(rba_browser_email_template)):
            query_parameters["rbaBrowserEmailTemplate"] = rba_browser_email_template
        if(not self._lr_object.is_null_or_whitespace(rba_browser_sms_template)):
            query_parameters["rbaBrowserSmsTemplate"] = rba_browser_sms_template
        if(not self._lr_object.is_null_or_whitespace(rba_city_email_template)):
            query_parameters["rbaCityEmailTemplate"] = rba_city_email_template
        if(not self._lr_object.is_null_or_whitespace(rba_city_sms_template)):
            query_parameters["rbaCitySmsTemplate"] = rba_city_sms_template
        if(not self._lr_object.is_null_or_whitespace(rba_country_email_template)):
            query_parameters["rbaCountryEmailTemplate"] = rba_country_email_template
        if(not self._lr_object.is_null_or_whitespace(rba_country_sms_template)):
            query_parameters["rbaCountrySmsTemplate"] = rba_country_sms_template
        if(not self._lr_object.is_null_or_whitespace(rba_ip_email_template)):
            query_parameters["rbaIpEmailTemplate"] = rba_ip_email_template
        if(not self._lr_object.is_null_or_whitespace(rba_ip_sms_template)):
            query_parameters["rbaIpSmsTemplate"] = rba_ip_sms_template
        if(not self._lr_object.is_null_or_whitespace(rba_oneclick_email_template)):
            query_parameters["rbaOneclickEmailTemplate"] = rba_oneclick_email_template
        if(not self._lr_object.is_null_or_whitespace(rba_otp_sms_template)):
            query_parameters["rbaOTPSmsTemplate"] = rba_otp_sms_template
        if(not self._lr_object.is_null_or_whitespace(sms_template)):
            query_parameters["smsTemplate"] = sms_template
        if(not self._lr_object.is_null_or_whitespace(verification_url)):
            query_parameters["verificationUrl"] = verification_url

        resource_path = "identity/v2/auth/login"
        return self._lr_object.execute("POST", resource_path, query_parameters, phone_authentication_model)



# -- coding: utf-8 --
# Created by LoginRadius Development Team
# Copyright 2019 LoginRadius Inc. All rights reserved.
#


class PINAuthenticationApi:

    def __init__(self, lr_object):
        """
        :param lr_object: this is the reference to the parent LoginRadius object.
        """
        self._lr_object = lr_object

    def pin_login(self, login_by_pin_model, session_token):
        """This API is used to login a user by pin and session token.
        
        Args:
            login_by_pin_model: Model Class containing Definition of payload for LoginByPin API
            session_token: Session Token of user
		
        Returns:
            Response containing User Profile Data and access token
        9.22
        """
        if(login_by_pin_model is None):
            raise Exception(self._lr_object.get_validation_message("login_by_pin_model"))

        if(self._lr_object.is_null_or_whitespace(session_token)):
            raise Exception(self._lr_object.get_validation_message("session_token"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["session_token"] = session_token

        resource_path = "identity/v2/auth/login/pin"
        return self._lr_object.execute("POST", resource_path, query_parameters, login_by_pin_model)

    def send_forgot_pin_email_by_email(self, forgot_pin_link_by_email_model, email_template=None, reset_pin_url=None):
        """This API sends the reset pin email to specified email address.
        
        Args:
            forgot_pin_link_by_email_model: Model Class containing Definition for Forgot Pin Link By Email API
            email_template: Email template name
            reset_pin_url: Reset PIN Url
		
        Returns:
            Response containing Definition of Complete Validation data
        42.1
        """
        if(forgot_pin_link_by_email_model is None):
            raise Exception(self._lr_object.get_validation_message("forgot_pin_link_by_email_model"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        if(not self._lr_object.is_null_or_whitespace(email_template)):
            query_parameters["emailTemplate"] = email_template
        if(not self._lr_object.is_null_or_whitespace(reset_pin_url)):
            query_parameters["resetPINUrl"] = reset_pin_url

        resource_path = "identity/v2/auth/pin/forgot/email"
        return self._lr_object.execute("POST", resource_path, query_parameters, forgot_pin_link_by_email_model)

    def send_forgot_pin_email_by_username(self, forgot_pin_link_by_user_name_model, email_template=None, reset_pin_url=None):
        """This API sends the reset pin email using username.
        
        Args:
            forgot_pin_link_by_user_name_model: Model Class containing Definition for Forgot Pin Link By UserName API
            email_template: Email template name
            reset_pin_url: Reset PIN Url
		
        Returns:
            Response containing Definition of Complete Validation data
        42.2
        """
        if(forgot_pin_link_by_user_name_model is None):
            raise Exception(self._lr_object.get_validation_message("forgot_pin_link_by_user_name_model"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        if(not self._lr_object.is_null_or_whitespace(email_template)):
            query_parameters["emailTemplate"] = email_template
        if(not self._lr_object.is_null_or_whitespace(reset_pin_url)):
            query_parameters["resetPINUrl"] = reset_pin_url

        resource_path = "identity/v2/auth/pin/forgot/username"
        return self._lr_object.execute("POST", resource_path, query_parameters, forgot_pin_link_by_user_name_model)

    def reset_pin_by_reset_token(self, reset_pin_by_reset_token):
        """This API is used to reset pin using reset token.
        
        Args:
            reset_pin_by_reset_token: Model Class containing Definition of payload for Reset Pin By Reset Token API
		
        Returns:
            Response containing Definition of Complete Validation data
        42.3
        """
        if(reset_pin_by_reset_token is None):
            raise Exception(self._lr_object.get_validation_message("reset_pin_by_reset_token"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        resource_path = "identity/v2/auth/pin/reset/token"
        return self._lr_object.execute("PUT", resource_path, query_parameters, reset_pin_by_reset_token)

    def reset_pin_by_email_and_security_answer(self, reset_pin_by_security_question_answer_and_email_model):
        """This API is used to reset pin using security question answer and email.
        
        Args:
            reset_pin_by_security_question_answer_and_email_model: Model Class containing Definition of payload for Reset Pin By Security Question and Email API
		
        Returns:
            Response containing Definition of Complete Validation data
        42.4
        """
        if(reset_pin_by_security_question_answer_and_email_model is None):
            raise Exception(self._lr_object.get_validation_message("reset_pin_by_security_question_answer_and_email_model"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        resource_path = "identity/v2/auth/pin/reset/securityanswer/email"
        return self._lr_object.execute("PUT", resource_path, query_parameters, reset_pin_by_security_question_answer_and_email_model)

    def reset_pin_by_username_and_security_answer(self, reset_pin_by_security_question_answer_and_username_model):
        """This API is used to reset pin using security question answer and username.
        
        Args:
            reset_pin_by_security_question_answer_and_username_model: Model Class containing Definition of payload for Reset Pin By Security Question and UserName API
		
        Returns:
            Response containing Definition of Complete Validation data
        42.5
        """
        if(reset_pin_by_security_question_answer_and_username_model is None):
            raise Exception(self._lr_object.get_validation_message("reset_pin_by_security_question_answer_and_username_model"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        resource_path = "identity/v2/auth/pin/reset/securityanswer/username"
        return self._lr_object.execute("PUT", resource_path, query_parameters, reset_pin_by_security_question_answer_and_username_model)

    def reset_pin_by_phone_and_security_answer(self, reset_pin_by_security_question_answer_and_phone_model):
        """This API is used to reset pin using security question answer and phone.
        
        Args:
            reset_pin_by_security_question_answer_and_phone_model: Model Class containing Definition of payload for Reset Pin By Security Question and Phone API
		
        Returns:
            Response containing Definition of Complete Validation data
        42.6
        """
        if(reset_pin_by_security_question_answer_and_phone_model is None):
            raise Exception(self._lr_object.get_validation_message("reset_pin_by_security_question_answer_and_phone_model"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        resource_path = "identity/v2/auth/pin/reset/securityanswer/phone"
        return self._lr_object.execute("PUT", resource_path, query_parameters, reset_pin_by_security_question_answer_and_phone_model)

    def send_forgot_pin_sms_by_phone(self, forgot_pin_otp_by_phone_model, sms_template=None):
        """This API sends the OTP to specified phone number
        
        Args:
            forgot_pin_otp_by_phone_model: Model Class containing Definition for Forgot Pin Otp By Phone API
            sms_template: 
		
        Returns:
            Response Containing Validation Data and SMS Data
        42.7
        """
        if(forgot_pin_otp_by_phone_model is None):
            raise Exception(self._lr_object.get_validation_message("forgot_pin_otp_by_phone_model"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        if(not self._lr_object.is_null_or_whitespace(sms_template)):
            query_parameters["smsTemplate"] = sms_template

        resource_path = "identity/v2/auth/pin/forgot/otp"
        return self._lr_object.execute("POST", resource_path, query_parameters, forgot_pin_otp_by_phone_model)

    def change_pin_by_access_token(self, access_token, change_pin_model):
        """This API is used to change a user's PIN using access token.
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            change_pin_model: Model Class containing Definition for change PIN Property
		
        Returns:
            Response containing Definition of Complete Validation data
        42.8
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))
        if(change_pin_model is None):
            raise Exception(self._lr_object.get_validation_message("change_pin_model"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        resource_path = "identity/v2/auth/pin/change"
        return self._lr_object.execute("PUT", resource_path, query_parameters, change_pin_model)

    def reset_pin_by_phone_and_otp(self, reset_pin_by_phone_and_otp_model):
        """This API is used to reset pin using phoneId and OTP.
        
        Args:
            reset_pin_by_phone_and_otp_model: Model Class containing Definition of payload for Reset Pin By Phone and Otp API
		
        Returns:
            Response containing Definition of Complete Validation data
        42.9
        """
        if(reset_pin_by_phone_and_otp_model is None):
            raise Exception(self._lr_object.get_validation_message("reset_pin_by_phone_and_otp_model"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        resource_path = "identity/v2/auth/pin/reset/otp/phone"
        return self._lr_object.execute("PUT", resource_path, query_parameters, reset_pin_by_phone_and_otp_model)

    def reset_pin_by_email_and_otp(self, reset_pin_by_email_and_otp_model):
        """This API is used to reset pin using email and OTP.
        
        Args:
            reset_pin_by_email_and_otp_model: Model Class containing Definition of payload for Reset Pin By Email and Otp API
		
        Returns:
            Response containing Definition of Complete Validation data
        42.10
        """
        if(reset_pin_by_email_and_otp_model is None):
            raise Exception(self._lr_object.get_validation_message("reset_pin_by_email_and_otp_model"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        resource_path = "identity/v2/auth/pin/reset/otp/email"
        return self._lr_object.execute("PUT", resource_path, query_parameters, reset_pin_by_email_and_otp_model)

    def reset_pin_by_username_and_otp(self, reset_pin_by_username_and_otp_model):
        """This API is used to reset pin using username and OTP.
        
        Args:
            reset_pin_by_username_and_otp_model: Model Class containing Definition of payload for Reset Pin By Username and Otp API
		
        Returns:
            Response containing Definition of Complete Validation data
        42.11
        """
        if(reset_pin_by_username_and_otp_model is None):
            raise Exception(self._lr_object.get_validation_message("reset_pin_by_username_and_otp_model"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        resource_path = "identity/v2/auth/pin/reset/otp/username"
        return self._lr_object.execute("PUT", resource_path, query_parameters, reset_pin_by_username_and_otp_model)

    def set_pin_by_pin_auth_token(self, pin_required_model, pin_auth_token):
        """This API is used to change a user's PIN using Pin Auth token.
        
        Args:
            pin_required_model: Model Class containing Definition for PIN
            pin_auth_token: Pin Auth Token
		
        Returns:
            Response containing User Profile Data and access token
        42.12
        """
        if(pin_required_model is None):
            raise Exception(self._lr_object.get_validation_message("pin_required_model"))

        if(self._lr_object.is_null_or_whitespace(pin_auth_token)):
            raise Exception(self._lr_object.get_validation_message("pin_auth_token"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["pinAuthToken"] = pin_auth_token

        resource_path = "identity/v2/auth/pin/set/pinauthtoken"
        return self._lr_object.execute("POST", resource_path, query_parameters, pin_required_model)

    def in_validate_pin_session_token(self, session_token):
        """This API is used to invalidate pin session token.
        
        Args:
            session_token: Session Token of user
		
        Returns:
            Response containing Definition of Complete Validation data
        44.1
        """

        if(self._lr_object.is_null_or_whitespace(session_token)):
            raise Exception(self._lr_object.get_validation_message("session_token"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["session_token"] = session_token

        resource_path = "identity/v2/auth/session_token/invalidate"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})



# -- coding: utf-8 --
# Created by LoginRadius Development Team
# Copyright 2019 LoginRadius Inc. All rights reserved.
#


class WebHookApi:

    def __init__(self, lr_object):
        """
        :param lr_object: this is the reference to the parent LoginRadius object.
        """
        self._lr_object = lr_object

    def get_web_hook_subscribed_u_r_ls(self, event):
        """This API is used to fatch all the subscribed URLs, for particular event
        
        Args:
            event: Allowed events: Login, Register, UpdateProfile, ResetPassword, ChangePassword, emailVerification, AddEmail, RemoveEmail, BlockAccount, DeleteAccount, SetUsername, AssignRoles, UnassignRoles, SetPassword, LinkAccount, UnlinkAccount, UpdatePhoneId, VerifyPhoneNumber, CreateCustomObject, UpdateCustomobject, DeleteCustomObject
		
        Returns:
            Response Containing List of Webhhook Data
        40.1
        """

        if(self._lr_object.is_null_or_whitespace(event)):
            raise Exception(self._lr_object.get_validation_message("event"))

        query_parameters = {}
        query_parameters["apikey"] = self._lr_object.get_api_key()
        query_parameters["apisecret"] = self._lr_object.get_api_secret()
        query_parameters["event"] = event

        resource_path = "api/v2/webhook"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def web_hook_subscribe(self, web_hook_subscribe_model):
        """API can be used to configure a WebHook on your LoginRadius site. Webhooks also work on subscribe and notification model, subscribe your hook and get a notification. Equivalent to RESThook but these provide security on basis of signature and RESThook work on unique URL. Following are the events that are allowed by LoginRadius to trigger a WebHook service call.
        
        Args:
            web_hook_subscribe_model: Model Class containing Definition of payload for Webhook Subscribe API
		
        Returns:
            Response containing Definition of Complete Validation data
        40.2
        """
        if(web_hook_subscribe_model is None):
            raise Exception(self._lr_object.get_validation_message("web_hook_subscribe_model"))

        query_parameters = {}
        query_parameters["apikey"] = self._lr_object.get_api_key()
        query_parameters["apisecret"] = self._lr_object.get_api_secret()

        resource_path = "api/v2/webhook"
        return self._lr_object.execute("POST", resource_path, query_parameters, web_hook_subscribe_model)

    def webhook_test(self):
        """API can be used to test a subscribed WebHook.
        
        Returns:
            Response containing Definition of Complete Validation data
        40.3
        """

        query_parameters = {}
        query_parameters["apikey"] = self._lr_object.get_api_key()
        query_parameters["apisecret"] = self._lr_object.get_api_secret()

        resource_path = "api/v2/webhook/test"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def web_hook_unsubscribe(self, web_hook_subscribe_model):
        """API can be used to unsubscribe a WebHook configured on your LoginRadius site.
        
        Args:
            web_hook_subscribe_model: Model Class containing Definition of payload for Webhook Subscribe API
		
        Returns:
            Response containing Definition of Delete Request
        40.4
        """
        if(web_hook_subscribe_model is None):
            raise Exception(self._lr_object.get_validation_message("web_hook_subscribe_model"))

        query_parameters = {}
        query_parameters["apikey"] = self._lr_object.get_api_key()
        query_parameters["apisecret"] = self._lr_object.get_api_secret()

        resource_path = "api/v2/webhook"
        return self._lr_object.execute("DELETE", resource_path, query_parameters, web_hook_subscribe_model)



# -- coding: utf-8 --
# Created by LoginRadius Development Team
# Copyright 2019 LoginRadius Inc. All rights reserved.
#


class PhoneAuthenticationApi:

    def __init__(self, lr_object):
        """
        :param lr_object: this is the reference to the parent LoginRadius object.
        """
        self._lr_object = lr_object

    def login_by_phone(self, phone_authentication_model, fields='', login_url=None,
        sms_template=None):
        """This API retrieves a copy of the user data based on the Phone
        
        Args:
            phone_authentication_model: Model Class containing Definition of payload for PhoneAuthenticationModel API
            fields: The fields parameter filters the API response so that the response only includes a specific set of fields
            login_url: Url where the user is logging from
            sms_template: SMS Template name
		
        Returns:
            Response containing User Profile Data and access token
        9.2.3
        """
        if(phone_authentication_model is None):
            raise Exception(self._lr_object.get_validation_message("phone_authentication_model"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        if(not self._lr_object.is_null_or_whitespace(fields)):
            query_parameters["fields"] = fields
        if(not self._lr_object.is_null_or_whitespace(login_url)):
            query_parameters["loginUrl"] = login_url
        if(not self._lr_object.is_null_or_whitespace(sms_template)):
            query_parameters["smsTemplate"] = sms_template

        resource_path = "identity/v2/auth/login"
        return self._lr_object.execute("POST", resource_path, query_parameters, phone_authentication_model)

    def forgot_password_by_phone_otp(self, phone, sms_template=None):
        """This API is used to send the OTP to reset the account password.
        
        Args:
            phone: New Phone Number
            sms_template: SMS Template name
		
        Returns:
            Response Containing Validation Data and SMS Data
        10.4
        """

        if(self._lr_object.is_null_or_whitespace(phone)):
            raise Exception(self._lr_object.get_validation_message("phone"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        if(not self._lr_object.is_null_or_whitespace(sms_template)):
            query_parameters["smsTemplate"] = sms_template

        body_parameters = {}
        body_parameters["phone"] = phone

        resource_path = "identity/v2/auth/password/otp"
        return self._lr_object.execute("POST", resource_path, query_parameters, body_parameters)

    def reset_password_by_phone_otp(self, reset_password_by_otp_model):
        """This API is used to reset the password
        
        Args:
            reset_password_by_otp_model: Model Class containing Definition of payload for ResetPasswordByOTP API
		
        Returns:
            Response containing Definition of Complete Validation data
        10.5
        """
        if(reset_password_by_otp_model is None):
            raise Exception(self._lr_object.get_validation_message("reset_password_by_otp_model"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        resource_path = "identity/v2/auth/password/otp"
        return self._lr_object.execute("PUT", resource_path, query_parameters, reset_password_by_otp_model)

    def phone_verification_by_otp(self, otp, phone, fields='',
        sms_template=None):
        """This API is used to validate the verification code sent to verify a user's phone number
        
        Args:
            otp: The Verification Code
            phone: New Phone Number
            fields: The fields parameter filters the API response so that the response only includes a specific set of fields
            sms_template: SMS Template name
		
        Returns:
            Response containing User Profile Data and access token
        11.1.1
        """

        if(self._lr_object.is_null_or_whitespace(otp)):
            raise Exception(self._lr_object.get_validation_message("otp"))

        if(self._lr_object.is_null_or_whitespace(phone)):
            raise Exception(self._lr_object.get_validation_message("phone"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["otp"] = otp
        if(not self._lr_object.is_null_or_whitespace(fields)):
            query_parameters["fields"] = fields
        if(not self._lr_object.is_null_or_whitespace(sms_template)):
            query_parameters["smsTemplate"] = sms_template

        body_parameters = {}
        body_parameters["phone"] = phone

        resource_path = "identity/v2/auth/phone/otp"
        return self._lr_object.execute("PUT", resource_path, query_parameters, body_parameters)

    def phone_verification_otp_by_access_token(self, access_token, otp, sms_template=None):
        """This API is used to consume the verification code sent to verify a user's phone number. Use this call for front-end purposes in cases where the user is already logged in by passing the user's access token.
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            otp: The Verification Code
            sms_template: SMS Template name
		
        Returns:
            Response containing Definition of Complete Validation data
        11.1.2
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        if(self._lr_object.is_null_or_whitespace(otp)):
            raise Exception(self._lr_object.get_validation_message("otp"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["otp"] = otp
        if(not self._lr_object.is_null_or_whitespace(sms_template)):
            query_parameters["smsTemplate"] = sms_template

        resource_path = "identity/v2/auth/phone/otp"
        return self._lr_object.execute("PUT", resource_path, query_parameters, {})

    def phone_resend_verification_otp(self, phone, sms_template=None):
        """This API is used to resend a verification OTP to verify a user's Phone Number. The user will receive a verification code that they will need to input
        
        Args:
            phone: New Phone Number
            sms_template: SMS Template name
		
        Returns:
            Response Containing Validation Data and SMS Data
        11.2.1
        """

        if(self._lr_object.is_null_or_whitespace(phone)):
            raise Exception(self._lr_object.get_validation_message("phone"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        if(not self._lr_object.is_null_or_whitespace(sms_template)):
            query_parameters["smsTemplate"] = sms_template

        body_parameters = {}
        body_parameters["phone"] = phone

        resource_path = "identity/v2/auth/phone/otp"
        return self._lr_object.execute("POST", resource_path, query_parameters, body_parameters)

    def phone_resend_verification_otp_by_token(self, access_token, phone, sms_template=None):
        """This API is used to resend a verification OTP to verify a user's Phone Number in cases in which an active token already exists
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            phone: New Phone Number
            sms_template: SMS Template name
		
        Returns:
            Response Containing Validation Data and SMS Data
        11.2.2
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        if(self._lr_object.is_null_or_whitespace(phone)):
            raise Exception(self._lr_object.get_validation_message("phone"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        if(not self._lr_object.is_null_or_whitespace(sms_template)):
            query_parameters["smsTemplate"] = sms_template

        body_parameters = {}
        body_parameters["phone"] = phone

        resource_path = "identity/v2/auth/phone/otp"
        return self._lr_object.execute("POST", resource_path, query_parameters, body_parameters)

    def update_phone_number(self, access_token, phone, sms_template=None):
        """This API is used to update the login Phone Number of users
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            phone: New Phone Number
            sms_template: SMS Template name
		
        Returns:
            Response Containing Validation Data and SMS Data
        11.5
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        if(self._lr_object.is_null_or_whitespace(phone)):
            raise Exception(self._lr_object.get_validation_message("phone"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        if(not self._lr_object.is_null_or_whitespace(sms_template)):
            query_parameters["smsTemplate"] = sms_template

        body_parameters = {}
        body_parameters["phone"] = phone

        resource_path = "identity/v2/auth/phone"
        return self._lr_object.execute("PUT", resource_path, query_parameters, body_parameters)

    def check_phone_number_availability(self, phone):
        """This API is used to check the Phone Number exists or not on your site.
        
        Args:
            phone: The Registered Phone Number
		
        Returns:
            Response containing Definition Complete ExistResponse data
        11.6
        """

        if(self._lr_object.is_null_or_whitespace(phone)):
            raise Exception(self._lr_object.get_validation_message("phone"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["phone"] = phone

        resource_path = "identity/v2/auth/phone"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def remove_phone_id_by_access_token(self, access_token):
        """This API is used to delete the Phone ID on a user's account via the access token
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
		
        Returns:
            Response containing Definition of Delete Request
        11.7
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        resource_path = "identity/v2/auth/phone"
        return self._lr_object.execute("DELETE", resource_path, query_parameters, {})

    def user_registration_by_phone(self, auth_user_registration_model, sott, fields='',
        options='', sms_template=None, verification_url=None, welcome_email_template=None):
        """This API registers the new users into your Cloud Storage and triggers the phone verification process.
        
        Args:
            auth_user_registration_model: Model Class containing Definition of payload for Auth User Registration API
            sott: LoginRadius Secured One Time Token
            fields: The fields parameter filters the API response so that the response only includes a specific set of fields
            options: PreventVerificationEmail (Specifying this value prevents the verification email from being sent. Only applicable if you have the optional email verification flow)
            sms_template: SMS Template name
            verification_url: Email verification url
            welcome_email_template: Name of the welcome email template
		
        Returns:
            Response containing Definition of Complete Validation, UserProfile data and Access Token
        17.1.2
        """
        if(auth_user_registration_model is None):
            raise Exception(self._lr_object.get_validation_message("auth_user_registration_model"))

        if(self._lr_object.is_null_or_whitespace(sott)):
            raise Exception(self._lr_object.get_validation_message("sott"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["sott"] = sott
        if(not self._lr_object.is_null_or_whitespace(fields)):
            query_parameters["fields"] = fields
        if(not self._lr_object.is_null_or_whitespace(options)):
            query_parameters["options"] = options
        if(not self._lr_object.is_null_or_whitespace(sms_template)):
            query_parameters["smsTemplate"] = sms_template
        if(not self._lr_object.is_null_or_whitespace(verification_url)):
            query_parameters["verificationUrl"] = verification_url
        if(not self._lr_object.is_null_or_whitespace(welcome_email_template)):
            query_parameters["welcomeEmailTemplate"] = welcome_email_template

        resource_path = "identity/v2/auth/register"
        return self._lr_object.execute("POST", resource_path, query_parameters, auth_user_registration_model)



# -- coding: utf-8 --
# Created by LoginRadius Development Team
# Copyright 2019 LoginRadius Inc. All rights reserved.
#


class CustomRegistrationDataApi:

    def __init__(self, lr_object):
        """
        :param lr_object: this is the reference to the parent LoginRadius object.
        """
        self._lr_object = lr_object

    def auth_get_registration_data(self, type, limit=None, parent_id=None,
        skip=None):
        """This API is used to retrieve dropdown data.
        
        Args:
            type: Type of the Datasource
            limit: Retrieve number of records at a time(max limit is 50)
            parent_id: Id of parent dropdown member(if any).
            skip: Skip number of records from start
		
        Returns:
            Complete user Registration data
        7.1
        """

        if(self._lr_object.is_null_or_whitespace(type)):
            raise Exception(self._lr_object.get_validation_message("type"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        if(limit is not None):
            query_parameters["limit"] = limit
        if(not self._lr_object.is_null_or_whitespace(parent_id)):
            query_parameters["parentId"] = parent_id
        if(skip is not None):
            query_parameters["skip"] = skip

        resource_path = "identity/v2/auth/registrationdata/" + type
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def validate_registration_data_code(self, code, record_id):
        """This API allows you to validate code for a particular dropdown member.
        
        Args:
            code: Secret Code
            record_id: Selected dropdown item’s record id
		
        Returns:
            Response containing Definition of Complete Validation data
        7.2
        """

        if(self._lr_object.is_null_or_whitespace(code)):
            raise Exception(self._lr_object.get_validation_message("code"))

        if(self._lr_object.is_null_or_whitespace(record_id)):
            raise Exception(self._lr_object.get_validation_message("record_id"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        body_parameters = {}
        body_parameters["code"] = code
        body_parameters["recordId"] = record_id

        resource_path = "identity/v2/auth/registrationdata/validatecode"
        return self._lr_object.execute("POST", resource_path, query_parameters, body_parameters)

    def get_registration_data(self, type, limit=None, parent_id=None,
        skip=None):
        """This API is used to retrieve dropdown data.
        
        Args:
            type: Type of the Datasource
            limit: Retrive number of records at a time(max limit is 50
            parent_id: Id of parent dropdown member(if any).
            skip: Skip number of records from start
		
        Returns:
            Complete user Registration data Fields
        16.1
        """

        if(self._lr_object.is_null_or_whitespace(type)):
            raise Exception(self._lr_object.get_validation_message("type"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["apiSecret"] = self._lr_object.get_api_secret()
        if(limit is not None):
            query_parameters["limit"] = limit
        if(not self._lr_object.is_null_or_whitespace(parent_id)):
            query_parameters["parentId"] = parent_id
        if(skip is not None):
            query_parameters["skip"] = skip

        resource_path = "identity/v2/manage/registrationdata/" + type
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def add_registration_data(self, registration_data_create_model_list):
        """This API allows you to fill data into a dropdown list which you have created for user Registration. For more details on how to use this API please see our Custom Registration Data Overview
        
        Args:
            registration_data_create_model_list: Model Class containing Definition of List of Registration Data
		
        Returns:
            Response containing Definition of Complete Validation data
        16.2
        """
        if(registration_data_create_model_list is None):
            raise Exception(self._lr_object.get_validation_message("registration_data_create_model_list"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["apiSecret"] = self._lr_object.get_api_secret()

        resource_path = "identity/v2/manage/registrationdata"
        return self._lr_object.execute("POST", resource_path, query_parameters, registration_data_create_model_list)

    def update_registration_data(self, registration_data_update_model, record_id):
        """This API allows you to update a dropdown item
        
        Args:
            registration_data_update_model: Model Class containing Definition of payload for Registration Data update API
            record_id: Registration data RecordId
		
        Returns:
            Complete user Registration data Field
        16.3
        """
        if(registration_data_update_model is None):
            raise Exception(self._lr_object.get_validation_message("registration_data_update_model"))

        if(self._lr_object.is_null_or_whitespace(record_id)):
            raise Exception(self._lr_object.get_validation_message("record_id"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["apiSecret"] = self._lr_object.get_api_secret()

        resource_path = "identity/v2/manage/registrationdata/" + record_id
        return self._lr_object.execute("PUT", resource_path, query_parameters, registration_data_update_model)

    def delete_registration_data(self, record_id):
        """This API allows you to delete an item from a dropdown list.
        
        Args:
            record_id: Registration data RecordId
		
        Returns:
            Response containing Definition of Delete Request
        16.4
        """

        if(self._lr_object.is_null_or_whitespace(record_id)):
            raise Exception(self._lr_object.get_validation_message("record_id"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["apiSecret"] = self._lr_object.get_api_secret()

        resource_path = "identity/v2/manage/registrationdata/" + record_id
        return self._lr_object.execute("DELETE", resource_path, query_parameters, {})

    def delete_all_records_by_data_source(self, type):
        """This API allows you to delete all records contained in a datasource.
        
        Args:
            type: Type of the Datasource
		
        Returns:
            Response containing Definition of Delete Request
        16.5
        """

        if(self._lr_object.is_null_or_whitespace(type)):
            raise Exception(self._lr_object.get_validation_message("type"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["apiSecret"] = self._lr_object.get_api_secret()

        resource_path = "identity/v2/manage/registrationdata/type/" + type
        return self._lr_object.execute("DELETE", resource_path, query_parameters, {})



# -- coding: utf-8 --
# Created by LoginRadius Development Team
# Copyright 2019 LoginRadius Inc. All rights reserved.
#


class NativeSocialApi:

    def __init__(self, lr_object):
        """
        :param lr_object: this is the reference to the parent LoginRadius object.
        """
        self._lr_object = lr_object

    def get_access_token_by_facebook_access_token(self, fb__access__token, social_app_name=None):
        """The API is used to get LoginRadius access token by sending Facebook's access token. It will be valid for the specific duration of time specified in the response.
        
        Args:
            fb__access__token: Facebook Access Token
            social_app_name: Name of Social provider APP
		
        Returns:
            Response containing Definition of Complete Token data
        20.3
        """

        if(self._lr_object.is_null_or_whitespace(fb__access__token)):
            raise Exception(self._lr_object.get_validation_message("fb__access__token"))

        query_parameters = {}
        query_parameters["fb_Access_Token"] = fb__access__token
        query_parameters["key"] = self._lr_object.get_api_key()
        if(not self._lr_object.is_null_or_whitespace(social_app_name)):
            query_parameters["socialAppName"] = social_app_name

        resource_path = "api/v2/access_token/facebook"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def get_access_token_by_twitter_access_token(self, tw__access__token, tw__token__secret, social_app_name=None):
        """The API is used to get LoginRadius access token by sending Twitter's access token. It will be valid for the specific duration of time specified in the response.
        
        Args:
            tw__access__token: Twitter Access Token
            tw__token__secret: Twitter Token Secret
            social_app_name: Name of Social provider APP
		
        Returns:
            Response containing Definition of Complete Token data
        20.4
        """

        if(self._lr_object.is_null_or_whitespace(tw__access__token)):
            raise Exception(self._lr_object.get_validation_message("tw__access__token"))

        if(self._lr_object.is_null_or_whitespace(tw__token__secret)):
            raise Exception(self._lr_object.get_validation_message("tw__token__secret"))

        query_parameters = {}
        query_parameters["key"] = self._lr_object.get_api_key()
        query_parameters["tw_Access_Token"] = tw__access__token
        query_parameters["tw_Token_Secret"] = tw__token__secret
        if(not self._lr_object.is_null_or_whitespace(social_app_name)):
            query_parameters["socialAppName"] = social_app_name

        resource_path = "api/v2/access_token/twitter"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def get_access_token_by_google_access_token(self, google__access__token, client_id=None, refresh_token=None,
        social_app_name=None):
        """The API is used to get LoginRadius access token by sending Google's access token. It will be valid for the specific duration of time specified in the response.
        
        Args:
            google__access__token: Google Access Token
            client_id: Google Client ID
            refresh_token: LoginRadius refresh token
            social_app_name: Name of Social provider APP
		
        Returns:
            Response containing Definition of Complete Token data
        20.5
        """

        if(self._lr_object.is_null_or_whitespace(google__access__token)):
            raise Exception(self._lr_object.get_validation_message("google__access__token"))

        query_parameters = {}
        query_parameters["google_Access_Token"] = google__access__token
        query_parameters["key"] = self._lr_object.get_api_key()
        if(not self._lr_object.is_null_or_whitespace(client_id)):
            query_parameters["client_id"] = client_id
        if(not self._lr_object.is_null_or_whitespace(refresh_token)):
            query_parameters["refresh_token"] = refresh_token
        if(not self._lr_object.is_null_or_whitespace(social_app_name)):
            query_parameters["socialAppName"] = social_app_name

        resource_path = "api/v2/access_token/google"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def get_access_token_by_google_j_w_t_access_token(self, id__token):
        """This API is used to Get LoginRadius Access Token using google jwt id token for google native mobile login/registration.
        
        Args:
            id__token: Google JWT id_token
		
        Returns:
            Response containing Definition of Complete Token data
        20.6
        """

        if(self._lr_object.is_null_or_whitespace(id__token)):
            raise Exception(self._lr_object.get_validation_message("id__token"))

        query_parameters = {}
        query_parameters["id_Token"] = id__token
        query_parameters["key"] = self._lr_object.get_api_key()

        resource_path = "api/v2/access_token/googlejwt"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def get_access_token_by_linkedin_access_token(self, ln__access__token, social_app_name=None):
        """The API is used to get LoginRadius access token by sending Linkedin's access token. It will be valid for the specific duration of time specified in the response.
        
        Args:
            ln__access__token: Linkedin Access Token
            social_app_name: Name of Social provider APP
		
        Returns:
            Response containing Definition of Complete Token data
        20.7
        """

        if(self._lr_object.is_null_or_whitespace(ln__access__token)):
            raise Exception(self._lr_object.get_validation_message("ln__access__token"))

        query_parameters = {}
        query_parameters["key"] = self._lr_object.get_api_key()
        query_parameters["ln_Access_Token"] = ln__access__token
        if(not self._lr_object.is_null_or_whitespace(social_app_name)):
            query_parameters["socialAppName"] = social_app_name

        resource_path = "api/v2/access_token/linkedin"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def get_access_token_by_foursquare_access_token(self, fs__access__token):
        """The API is used to get LoginRadius access token by sending Foursquare's access token. It will be valid for the specific duration of time specified in the response.
        
        Args:
            fs__access__token: Foursquare Access Token
		
        Returns:
            Response containing Definition of Complete Token data
        20.8
        """

        if(self._lr_object.is_null_or_whitespace(fs__access__token)):
            raise Exception(self._lr_object.get_validation_message("fs__access__token"))

        query_parameters = {}
        query_parameters["fs_Access_Token"] = fs__access__token
        query_parameters["key"] = self._lr_object.get_api_key()

        resource_path = "api/v2/access_token/foursquare"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def get_access_token_by_apple_id_code(self, code, social_app_name=None):
        """The API is used to get LoginRadius access token by sending a valid Apple ID OAuth Code. It will be valid for the specific duration of time specified in the response.
        
        Args:
            code: Apple Code
            social_app_name: Name of Social provider APP
		
        Returns:
            Response containing Definition of Complete Token data
        20.12
        """

        if(self._lr_object.is_null_or_whitespace(code)):
            raise Exception(self._lr_object.get_validation_message("code"))

        query_parameters = {}
        query_parameters["code"] = code
        query_parameters["key"] = self._lr_object.get_api_key()
        if(not self._lr_object.is_null_or_whitespace(social_app_name)):
            query_parameters["socialAppName"] = social_app_name

        resource_path = "api/v2/access_token/apple"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def get_access_token_by_we_chat_code(self, code):
        """This API is used to retrieve a LoginRadius access token by passing in a valid WeChat OAuth Code.
        
        Args:
            code: WeChat Code
		
        Returns:
            Response containing Definition of Complete Token data
        20.13
        """

        if(self._lr_object.is_null_or_whitespace(code)):
            raise Exception(self._lr_object.get_validation_message("code"))

        query_parameters = {}
        query_parameters["code"] = code
        query_parameters["key"] = self._lr_object.get_api_key()

        resource_path = "api/v2/access_token/wechat"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def get_access_token_by_vkontakte_access_token(self, vk_access_token):
        """The API is used to get LoginRadius access token by sending Vkontakte's access token. It will be valid for the specific duration of time specified in the response.
        
        Args:
            vk_access_token: Vkontakte Access Token
		
        Returns:
            Response containing Definition of Complete Token data
        20.15
        """

        if(self._lr_object.is_null_or_whitespace(vk_access_token)):
            raise Exception(self._lr_object.get_validation_message("vk_access_token"))

        query_parameters = {}
        query_parameters["key"] = self._lr_object.get_api_key()
        query_parameters["vk_access_token"] = vk_access_token

        resource_path = "api/v2/access_token/vkontakte"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def get_access_token_by_google_auth_code(self, google_authcode, social_app_name=None):
        """The API is used to get LoginRadius access token by sending Google's AuthCode. It will be valid for the specific duration of time specified in the response.
        
        Args:
            google_authcode: Google AuthCode
            social_app_name: Name of Social provider APP
		
        Returns:
            Response containing Definition of Complete Token data
        20.16
        """

        if(self._lr_object.is_null_or_whitespace(google_authcode)):
            raise Exception(self._lr_object.get_validation_message("google_authcode"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["google_authcode"] = google_authcode
        if(not self._lr_object.is_null_or_whitespace(social_app_name)):
            query_parameters["socialAppName"] = social_app_name

        resource_path = "api/v2/access_token/google"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})



# -- coding: utf-8 --
# Created by LoginRadius Development Team
# Copyright 2019 LoginRadius Inc. All rights reserved.
#


class ReAuthenticationApi:

    def __init__(self, lr_object):
        """
        :param lr_object: this is the reference to the parent LoginRadius object.
        """
        self._lr_object = lr_object

    def mfa_re_authenticate(self, access_token, sms_template2_f_a=None):
        """This API is used to trigger the Multi-Factor Autentication workflow for the provided access token
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            sms_template2_f_a: SMS Template Name
		
        Returns:
            Response containing Definition of Complete Multi-Factor Authentication Settings data
        14.3
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        if(not self._lr_object.is_null_or_whitespace(sms_template2_f_a)):
            query_parameters["smsTemplate2FA"] = sms_template2_f_a

        resource_path = "identity/v2/auth/account/reauth/2fa"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def mfa_re_authenticate_by_otp(self, access_token, reauth_by_otp_model):
        """This API is used to re-authenticate via Multi-factor authentication by passing the One Time Password received via SMS
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            reauth_by_otp_model: Model Class containing Definition for MFA Reauthentication by OTP
		
        Returns:
            Complete user Multi-Factor Authentication Token data
        14.4
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))
        if(reauth_by_otp_model is None):
            raise Exception(self._lr_object.get_validation_message("reauth_by_otp_model"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        resource_path = "identity/v2/auth/account/reauth/2fa/otp"
        return self._lr_object.execute("PUT", resource_path, query_parameters, reauth_by_otp_model)

    def mfa_re_authenticate_by_backup_code(self, access_token, reauth_by_backup_code_model):
        """This API is used to re-authenticate by set of backup codes via access token on the site that has Multi-factor authentication enabled in re-authentication for the user that does not have the device
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            reauth_by_backup_code_model: Model Class containing Definition for MFA Reauthentication by Backup code
		
        Returns:
            Complete user Multi-Factor Authentication Token data
        14.5
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))
        if(reauth_by_backup_code_model is None):
            raise Exception(self._lr_object.get_validation_message("reauth_by_backup_code_model"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        resource_path = "identity/v2/auth/account/reauth/2fa/backupcode"
        return self._lr_object.execute("PUT", resource_path, query_parameters, reauth_by_backup_code_model)

    def mfa_re_authenticate_by_google_auth(self, access_token, reauth_by_google_authenticator_code_model):
        """This API is used to re-authenticate via Multi-factor-authentication by passing the google authenticator code
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            reauth_by_google_authenticator_code_model: Model Class containing Definition for MFA Reauthentication by Google Authenticator
		
        Returns:
            Complete user Multi-Factor Authentication Token data
        14.6
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))
        if(reauth_by_google_authenticator_code_model is None):
            raise Exception(self._lr_object.get_validation_message("reauth_by_google_authenticator_code_model"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        resource_path = "identity/v2/auth/account/reauth/2fa/googleauthenticatorcode"
        return self._lr_object.execute("PUT", resource_path, query_parameters, reauth_by_google_authenticator_code_model)

    def mfa_re_authenticate_by_password(self, access_token, password_event_based_auth_model_with_lockout, sms_template2_f_a=None):
        """This API is used to re-authenticate via Multi-factor-authentication by passing the password
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            password_event_based_auth_model_with_lockout: Model Class containing Definition of payload for PasswordEventBasedAuthModel with Lockout API
            sms_template2_f_a: SMS Template Name
		
        Returns:
            Complete user Multi-Factor Authentication Token data
        14.7
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))
        if(password_event_based_auth_model_with_lockout is None):
            raise Exception(self._lr_object.get_validation_message("password_event_based_auth_model_with_lockout"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        if(not self._lr_object.is_null_or_whitespace(sms_template2_f_a)):
            query_parameters["smsTemplate2FA"] = sms_template2_f_a

        resource_path = "identity/v2/auth/account/reauth/password"
        return self._lr_object.execute("PUT", resource_path, query_parameters, password_event_based_auth_model_with_lockout)

    def verify_multi_factor_otp_reauthentication(self, event_based_multi_factor_token, uid):
        """This API is used on the server-side to validate and verify the re-authentication token created by the MFA re-authentication API. This API checks re-authentications created by OTP.
        
        Args:
            event_based_multi_factor_token: Model Class containing Definition for SecondFactorValidationToken
            uid: UID, the unified identifier for each user account
		
        Returns:
            Response containing Definition of Complete Validation data
        18.38
        """
        if(event_based_multi_factor_token is None):
            raise Exception(self._lr_object.get_validation_message("event_based_multi_factor_token"))

        if(self._lr_object.is_null_or_whitespace(uid)):
            raise Exception(self._lr_object.get_validation_message("uid"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["apiSecret"] = self._lr_object.get_api_secret()

        resource_path = "identity/v2/manage/account/" + uid + "/reauth/2fa"
        return self._lr_object.execute("POST", resource_path, query_parameters, event_based_multi_factor_token)

    def verify_multi_factor_password_reauthentication(self, event_based_multi_factor_token, uid):
        """This API is used on the server-side to validate and verify the re-authentication token created by the MFA re-authentication API. This API checks re-authentications created by password.
        
        Args:
            event_based_multi_factor_token: Model Class containing Definition for SecondFactorValidationToken
            uid: UID, the unified identifier for each user account
		
        Returns:
            Response containing Definition of Complete Validation data
        18.39
        """
        if(event_based_multi_factor_token is None):
            raise Exception(self._lr_object.get_validation_message("event_based_multi_factor_token"))

        if(self._lr_object.is_null_or_whitespace(uid)):
            raise Exception(self._lr_object.get_validation_message("uid"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["apiSecret"] = self._lr_object.get_api_secret()

        resource_path = "identity/v2/manage/account/" + uid + "/reauth/password"
        return self._lr_object.execute("POST", resource_path, query_parameters, event_based_multi_factor_token)

    def verify_multi_factor_pin_reauthentication(self, event_based_multi_factor_token, uid):
        """This API is used on the server-side to validate and verify the re-authentication token created by the MFA re-authentication API. This API checks re-authentications created by PIN.
        
        Args:
            event_based_multi_factor_token: Model Class containing Definition for SecondFactorValidationToken
            uid: UID, the unified identifier for each user account
		
        Returns:
            Response containing Definition of Complete Validation data
        18.40
        """
        if(event_based_multi_factor_token is None):
            raise Exception(self._lr_object.get_validation_message("event_based_multi_factor_token"))

        if(self._lr_object.is_null_or_whitespace(uid)):
            raise Exception(self._lr_object.get_validation_message("uid"))

        query_parameters = {}
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["apiSecret"] = self._lr_object.get_api_secret()

        resource_path = "identity/v2/manage/account/" + uid + "/reauth/pin"
        return self._lr_object.execute("POST", resource_path, query_parameters, event_based_multi_factor_token)

    def verify_pin_authentication(self, access_token, pin_auth_event_based_auth_model_with_lockout, sms_template2_f_a=None):
        """This API is used to validate the triggered MFA authentication flow with a password.
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            pin_auth_event_based_auth_model_with_lockout: Model Class containing Definition of payload for PIN
            sms_template2_f_a: SMS Template Name
		
        Returns:
            Response containing Definition response of MFA reauthentication
        42.13
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))
        if(pin_auth_event_based_auth_model_with_lockout is None):
            raise Exception(self._lr_object.get_validation_message("pin_auth_event_based_auth_model_with_lockout"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        if(not self._lr_object.is_null_or_whitespace(sms_template2_f_a)):
            query_parameters["smsTemplate2FA"] = sms_template2_f_a

        resource_path = "identity/v2/auth/account/reauth/pin"
        return self._lr_object.execute("PUT", resource_path, query_parameters, pin_auth_event_based_auth_model_with_lockout)

    def re_auth_validate_email_otp(self, access_token, reauth_by_email_otp_model):
        """This API is used to validate the triggered MFA authentication flow with an Email OTP.
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            reauth_by_email_otp_model: payload
		
        Returns:
            Response containing Definition response of MFA reauthentication
        42.14
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))
        if(reauth_by_email_otp_model is None):
            raise Exception(self._lr_object.get_validation_message("reauth_by_email_otp_model"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        resource_path = "identity/v2/auth/account/reauth/2fa/otp/email/verify"
        return self._lr_object.execute("PUT", resource_path, query_parameters, reauth_by_email_otp_model)

    def re_auth_send_email_otp(self, access_token, email_id, email_template2_f_a=None):
        """This API is used to send the MFA Email OTP to the email for Re-authentication
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            email_id: EmailId
            email_template2_f_a: EmailTemplate2FA
		
        Returns:
            Response containing Definition of Complete Validation data
        42.15
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))

        if(self._lr_object.is_null_or_whitespace(email_id)):
            raise Exception(self._lr_object.get_validation_message("email_id"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()
        query_parameters["emailId"] = email_id
        if(not self._lr_object.is_null_or_whitespace(email_template2_f_a)):
            query_parameters["emailTemplate2FA"] = email_template2_f_a

        resource_path = "identity/v2/auth/account/reauth/2fa/otp/email"
        return self._lr_object.execute("GET", resource_path, query_parameters, {})

    def re_auth_by_security_question(self, access_token, security_question_answer_update_model):
        """This API is used to validate the triggered MFA re-authentication flow with security questions answers.
        
        Args:
            access_token: Uniquely generated identifier key by LoginRadius that is activated after successful authentication.
            security_question_answer_update_model: payload
		
        Returns:
            Response containing Definition response of MFA reauthentication
        42.16
        """

        if(self._lr_object.is_null_or_whitespace(access_token)):
            raise Exception(self._lr_object.get_validation_message("access_token"))
        if(security_question_answer_update_model is None):
            raise Exception(self._lr_object.get_validation_message("security_question_answer_update_model"))

        query_parameters = {}
        query_parameters["access_token"] = access_token
        query_parameters["apiKey"] = self._lr_object.get_api_key()

        resource_path = "identity/v2/auth/account/reauth/2fa/securityquestionanswer/verify"
        return self._lr_object.execute("POST", resource_path, query_parameters, security_question_answer_update_model)
